@@ -53,7 +53,7 @@ struct ADomainScanData {
 
 static bool ADomIsWildAlias(char const *pszAlias);
 static int ADomCalcAliasHash(char const *const *ppszTabTokens, int const *piFieldsIdx,
-			     SYS_UINT32 * puHashVal, bool bCaseSens);
+			     TabIdxUINT *puHashVal, bool bCaseSens);
 static int ADomRebuildADomainIndexes(char const *pszADomainFilePath);
 static char *ADomGetADomainFilePath(char *pszADomainFilePath, int iMaxPath);
 static int ADomLookupDomainLK(const char *pszADomainFilePath, const char *pszADomain,
@@ -62,80 +62,63 @@ static int ADomLookupDomainLK(const char *pszADomainFilePath, const char *pszADo
 static int iIdxADomain_Alias[] = {
 	adomADomain,
 
-	INDEX_SEQUENCE_TERMINATOR
+		INDEX_SEQUENCE_TERMINATOR
 };
 
 static bool ADomIsWildAlias(char const *pszAlias)
 {
-
-	return ((strchr(pszAlias, '*') != NULL) || (strchr(pszAlias, '?') != NULL));
-
+	return (strchr(pszAlias, '*') != NULL) || (strchr(pszAlias, '?') != NULL);
 }
 
 static int ADomCalcAliasHash(char const *const *ppszTabTokens, int const *piFieldsIdx,
-			     SYS_UINT32 * puHashVal, bool bCaseSens)
+			     TabIdxUINT *puHashVal, bool bCaseSens)
 {
-///////////////////////////////////////////////////////////////////////////////
-//  This will group wild alias ( * ? )
-///////////////////////////////////////////////////////////////////////////////
+	/* This will group wild alias ( * ? ) */
 	int iFieldsCount = StrStringsCount(ppszTabTokens);
 
-	if ((iFieldsCount > adomADomain) && ADomIsWildAlias(ppszTabTokens[adomADomain])) {
+	if (iFieldsCount > adomADomain && ADomIsWildAlias(ppszTabTokens[adomADomain])) {
 		*puHashVal = WILD_ADOMAIN_HASH;
 
-		return (0);
+		return 0;
 	}
 
-	return (TbixCalculateHash(ppszTabTokens, piFieldsIdx, puHashVal, bCaseSens));
-
+	return TbixCalculateHash(ppszTabTokens, piFieldsIdx, puHashVal, bCaseSens);
 }
 
 int ADomCheckDomainsIndexes(void)
 {
-
 	char szADomainFilePath[SYS_MAX_PATH] = "";
 
 	ADomGetADomainFilePath(szADomainFilePath, sizeof(szADomainFilePath));
 
-///////////////////////////////////////////////////////////////////////////////
-//  Align RmtDomain-RmtName index
-///////////////////////////////////////////////////////////////////////////////
+	/* Align RmtDomain-RmtName index */
 	if (TbixCheckIndex(szADomainFilePath, iIdxADomain_Alias, false, ADomCalcAliasHash) < 0)
-		return (ErrGetErrorCode());
-
-	return (0);
+		return ErrGetErrorCode();
 
+	return 0;
 }
 
 static int ADomRebuildADomainIndexes(char const *pszADomainFilePath)
 {
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild RmtDomain-RmtName index
-///////////////////////////////////////////////////////////////////////////////
+	/* Rebuild RmtDomain-RmtName index */
 	if (TbixCreateIndex(pszADomainFilePath, iIdxADomain_Alias, false, ADomCalcAliasHash) < 0)
-		return (ErrGetErrorCode());
-
-	return (0);
+		return ErrGetErrorCode();
 
+	return 0;
 }
 
 static char *ADomGetADomainFilePath(char *pszADomainFilePath, int iMaxPath)
 {
-
 	CfgGetRootPath(pszADomainFilePath, iMaxPath);
-
 	StrNCat(pszADomainFilePath, ADOMAIN_FILE, iMaxPath);
 
-	return (pszADomainFilePath);
-
+	return pszADomainFilePath;
 }
 
 static int ADomLookupDomainLK(const char *pszADomainFilePath, const char *pszADomain,
 			      char *pszDomain, bool bWildMatch)
 {
-///////////////////////////////////////////////////////////////////////////////
-//  Lookup record using the specified index ( lookup precise aliases )
-///////////////////////////////////////////////////////////////////////////////
+	/* Lookup record using the specified index ( lookup precise aliases ) */
 	char **ppszTabTokens = TbixLookup(pszADomainFilePath, iIdxADomain_Alias, false,
 					  pszADomain,
 					  NULL);
@@ -146,33 +129,26 @@ static int ADomLookupDomainLK(const char *pszADomainFilePath, const char *pszADo
 
 		StrFreeStrings(ppszTabTokens);
 
-		return (1);
+		return 1;
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  We can stop here if wild alias matching is not required
-///////////////////////////////////////////////////////////////////////////////
+	/* We can stop here if wild alias matching is not required */
 	if (!bWildMatch)
-		return (0);
+		return 0;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Lookup record using the specified index ( lookup wild aliases grouped
-//  under WILD_ADOMAIN_HASH hash key )
-///////////////////////////////////////////////////////////////////////////////
+	/* Lookup record using the specified index ( lookup wild aliases grouped */
+	/* under WILD_ADOMAIN_HASH hash key ) */
+	TabIdxUINT uLkHVal = WILD_ADOMAIN_HASH;
 	INDEX_HANDLE hIndexLookup = TbixOpenHandle(pszADomainFilePath, iIdxADomain_Alias,
-						   WILD_ADOMAIN_HASH);
+						   &uLkHVal, 1);
 
 	if (hIndexLookup != INVALID_INDEX_HANDLE) {
-		int iNumRecords = TbixLookedUpRecords(hIndexLookup);
-
-		for (int ii = 0; ii < iNumRecords; ii++) {
-			char **ppszTabTokens = TbixGetRecord(hIndexLookup, ii);
-
-			if (ppszTabTokens == NULL)
-				continue;
+		char **ppszTabTokens;
 
+		for (ppszTabTokens = TbixFirstRecord(hIndexLookup); ppszTabTokens != NULL;
+		     ppszTabTokens = TbixNextRecord(hIndexLookup)) {
 			int iFieldsCount = StrStringsCount(ppszTabTokens);
 
-			if ((iFieldsCount >= adomMax) &&
+			if (iFieldsCount >= adomMax &&
 			    StrIWildMatch(pszADomain, ppszTabTokens[adomADomain])) {
 				if (pszDomain != NULL)
 					StrNCpy(pszDomain, ppszTabTokens[adomDomain],
@@ -181,22 +157,18 @@ static int ADomLookupDomainLK(const char *pszADomainFilePath, const char *pszADo
 				StrFreeStrings(ppszTabTokens);
 				TbixCloseHandle(hIndexLookup);
 
-				return (1);
+				return 1;
 			}
-
 			StrFreeStrings(ppszTabTokens);
 		}
-
 		TbixCloseHandle(hIndexLookup);
 	}
 
-	return (0);
-
+	return 0;
 }
 
 int ADomLookupDomain(const char *pszADomain, char *pszDomain, bool bWildMatch)
 {
-
 	char szADomainFilePath[SYS_MAX_PATH] = "";
 
 	ADomGetADomainFilePath(szADomainFilePath, sizeof(szADomainFilePath));
@@ -206,20 +178,18 @@ int ADomLookupDomain(const char *pszADomain, char *pszDomain, bool bWildMatch)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (0);
+		return 0;
 
 	int iLookupResult = ADomLookupDomainLK(szADomainFilePath, pszADomain,
 					       pszDomain, bWildMatch);
 
 	RLckUnlockSH(hResLock);
 
-	return (iLookupResult);
-
+	return iLookupResult;
 }
 
 int ADomAddADomain(char const *pszADomain, char const *pszDomain)
 {
-
 	char szADomainFilePath[SYS_MAX_PATH] = "";
 
 	ADomGetADomainFilePath(szADomainFilePath, sizeof(szADomainFilePath));
@@ -229,7 +199,7 @@ int ADomAddADomain(char const *pszADomain, char const *pszDomain)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	FILE *pDomainsFile = fopen(szADomainFilePath, "r+t");
 
@@ -237,7 +207,7 @@ int ADomAddADomain(char const *pszADomain, char const *pszDomain)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_ADOMAIN_FILE_NOT_FOUND);
-		return (ERR_ADOMAIN_FILE_NOT_FOUND);
+		return ERR_ADOMAIN_FILE_NOT_FOUND;
 	}
 
 	char szADomainLine[ADOMAIN_LINE_MAX] = "";
@@ -250,49 +220,39 @@ int ADomAddADomain(char const *pszADomain, char const *pszDomain)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= adomMax) &&
-		    (stricmp(pszADomain, ppszStrings[adomADomain]) == 0)) {
+		if (iFieldsCount >= adomMax &&
+		    stricmp(pszADomain, ppszStrings[adomADomain]) == 0) {
 			StrFreeStrings(ppszStrings);
 			fclose(pDomainsFile);
 			RLckUnlockEX(hResLock);
 
 			ErrSetErrorCode(ERR_ADOMAIN_EXIST);
-			return (ERR_ADOMAIN_EXIST);
+			return ERR_ADOMAIN_EXIST;
 		}
 
 		StrFreeStrings(ppszStrings);
 	}
-
 	fseek(pDomainsFile, 0, SEEK_END);
-
 	fprintf(pDomainsFile, "\"%s\"\t\"%s\"\n", pszADomain, pszDomain);
-
 	fclose(pDomainsFile);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild indexes
-///////////////////////////////////////////////////////////////////////////////
+	/* Rebuild indexes */
 	if (ADomRebuildADomainIndexes(szADomainFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
-
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 int ADomRemoveADomain(char const *pszADomain)
 {
-
 	char szADomainFilePath[SYS_MAX_PATH] = "";
-
-	ADomGetADomainFilePath(szADomainFilePath, sizeof(szADomainFilePath));
-
 	char szTmpFile[SYS_MAX_PATH] = "";
 
+	ADomGetADomainFilePath(szADomainFilePath, sizeof(szADomainFilePath));
 	SysGetTmpFile(szTmpFile);
 
 	char szResLock[SYS_MAX_PATH] = "";
@@ -301,18 +261,18 @@ int ADomRemoveADomain(char const *pszADomain)
 
 	if (hResLock == INVALID_RLCK_HANDLE) {
 		ErrorPush();
-		CheckRemoveFile(szTmpFile);
-		return (ErrorPop());
+		SysRemove(szTmpFile);
+		return ErrorPop();
 	}
 
 	FILE *pDomainsFile = fopen(szADomainFilePath, "rt");
 
 	if (pDomainsFile == NULL) {
 		RLckUnlockEX(hResLock);
-		CheckRemoveFile(szTmpFile);
+		SysRemove(szTmpFile);
 
 		ErrSetErrorCode(ERR_ADOMAIN_FILE_NOT_FOUND);
-		return (ERR_ADOMAIN_FILE_NOT_FOUND);
+		return ERR_ADOMAIN_FILE_NOT_FOUND;
 	}
 
 	FILE *pTmpFile = fopen(szTmpFile, "wt");
@@ -320,10 +280,10 @@ int ADomRemoveADomain(char const *pszADomain)
 	if (pTmpFile == NULL) {
 		fclose(pDomainsFile);
 		RLckUnlockEX(hResLock);
-		CheckRemoveFile(szTmpFile);
+		SysRemove(szTmpFile);
 
 		ErrSetErrorCode(ERR_FILE_CREATE, szTmpFile);
-		return (ERR_FILE_CREATE);
+		return ERR_FILE_CREATE;
 	}
 
 	int iADomainFound = 0;
@@ -337,17 +297,13 @@ int ADomRemoveADomain(char const *pszADomain)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= adomMax) &&
-		    (stricmp(pszADomain, ppszStrings[adomADomain]) == 0)) {
-
+		if (iFieldsCount >= adomMax &&
+		    stricmp(pszADomain, ppszStrings[adomADomain]) == 0) {
 			++iADomainFound;
-
 		} else
 			fprintf(pTmpFile, "%s\n", szADomainLine);
-
 		StrFreeStrings(ppszStrings);
 	}
-
 	fclose(pDomainsFile);
 	fclose(pTmpFile);
 
@@ -356,52 +312,31 @@ int ADomRemoveADomain(char const *pszADomain)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_ADOMAIN_NOT_FOUND);
-		return (ERR_ADOMAIN_NOT_FOUND);
+		return ERR_ADOMAIN_NOT_FOUND;
 	}
-
-	char szTmpADomainFilePath[SYS_MAX_PATH] = "";
-
-	sprintf(szTmpADomainFilePath, "%s.tmp", szADomainFilePath);
-
-	if (MscMoveFile(szADomainFilePath, szTmpADomainFilePath) < 0) {
-		ErrorPush();
-		RLckUnlockEX(hResLock);
-		return (ErrorPop());
-	}
-
 	if (MscMoveFile(szTmpFile, szADomainFilePath) < 0) {
 		ErrorPush();
-		MscMoveFile(szTmpADomainFilePath, szADomainFilePath);
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
-	SysRemove(szTmpADomainFilePath);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild indexes
-///////////////////////////////////////////////////////////////////////////////
+	/* Rebuild indexes */
 	if (ADomRebuildADomainIndexes(szADomainFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
-
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 int ADomRemoveLinkedDomains(char const *pszDomain)
 {
-
 	char szADomainFilePath[SYS_MAX_PATH] = "";
-
-	ADomGetADomainFilePath(szADomainFilePath, sizeof(szADomainFilePath));
-
 	char szTmpFile[SYS_MAX_PATH] = "";
 
+	ADomGetADomainFilePath(szADomainFilePath, sizeof(szADomainFilePath));
 	SysGetTmpFile(szTmpFile);
 
 	char szResLock[SYS_MAX_PATH] = "";
@@ -410,18 +345,18 @@ int ADomRemoveLinkedDomains(char const *pszDomain)
 
 	if (hResLock == INVALID_RLCK_HANDLE) {
 		ErrorPush();
-		CheckRemoveFile(szTmpFile);
-		return (ErrorPop());
+		SysRemove(szTmpFile);
+		return ErrorPop();
 	}
 
 	FILE *pDomainsFile = fopen(szADomainFilePath, "rt");
 
 	if (pDomainsFile == NULL) {
 		RLckUnlockEX(hResLock);
-		CheckRemoveFile(szTmpFile);
+		SysRemove(szTmpFile);
 
 		ErrSetErrorCode(ERR_ADOMAIN_FILE_NOT_FOUND);
-		return (ERR_ADOMAIN_FILE_NOT_FOUND);
+		return ERR_ADOMAIN_FILE_NOT_FOUND;
 	}
 
 	FILE *pTmpFile = fopen(szTmpFile, "wt");
@@ -429,10 +364,10 @@ int ADomRemoveLinkedDomains(char const *pszDomain)
 	if (pTmpFile == NULL) {
 		fclose(pDomainsFile);
 		RLckUnlockEX(hResLock);
-		CheckRemoveFile(szTmpFile);
+		SysRemove(szTmpFile);
 
 		ErrSetErrorCode(ERR_FILE_CREATE, szTmpFile);
-		return (ERR_FILE_CREATE);
+		return ERR_FILE_CREATE;
 	}
 
 	int iDomainFound = 0;
@@ -446,63 +381,41 @@ int ADomRemoveLinkedDomains(char const *pszDomain)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= adomMax) &&
-		    (stricmp(pszDomain, ppszStrings[adomDomain]) == 0)) {
+		if (iFieldsCount >= adomMax &&
+		    stricmp(pszDomain, ppszStrings[adomDomain]) == 0) {
 
 			++iDomainFound;
-
 		} else
 			fprintf(pTmpFile, "%s\n", szADomainLine);
-
 		StrFreeStrings(ppszStrings);
 	}
-
 	fclose(pDomainsFile);
 	fclose(pTmpFile);
 
 	if (iDomainFound == 0) {
 		SysRemove(szTmpFile);
 		RLckUnlockEX(hResLock);
-		return (0);
+		return 0;
 	}
-
-	char szTmpADomainFilePath[SYS_MAX_PATH] = "";
-
-	sprintf(szTmpADomainFilePath, "%s.tmp", szADomainFilePath);
-
-	if (MscMoveFile(szADomainFilePath, szTmpADomainFilePath) < 0) {
-		ErrorPush();
-		RLckUnlockEX(hResLock);
-		return (ErrorPop());
-	}
-
 	if (MscMoveFile(szTmpFile, szADomainFilePath) < 0) {
 		ErrorPush();
-		MscMoveFile(szTmpADomainFilePath, szADomainFilePath);
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
-	SysRemove(szTmpADomainFilePath);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild indexes
-///////////////////////////////////////////////////////////////////////////////
+	/* Rebuild indexes */
 	if (ADomRebuildADomainIndexes(szADomainFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
-
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 int ADomGetADomainFileSnapShot(const char *pszFileName)
 {
-
 	char szADomainFilePath[SYS_MAX_PATH] = "";
 
 	ADomGetADomainFilePath(szADomainFilePath, sizeof(szADomainFilePath));
@@ -512,67 +425,55 @@ int ADomGetADomainFileSnapShot(const char *pszFileName)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	if (MscCopyFile(pszFileName, szADomainFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockSH(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
-
 	RLckUnlockSH(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 ADOMAIN_HANDLE ADomOpenDB(void)
 {
-
 	ADomainScanData *pDSD = (ADomainScanData *) SysAlloc(sizeof(ADomainScanData));
 
 	if (pDSD == NULL)
-		return (INVALID_ADOMAIN_HANDLE);
+		return INVALID_ADOMAIN_HANDLE;
 
 	SysGetTmpFile(pDSD->szTmpDBFile);
-
 	if (ADomGetADomainFileSnapShot(pDSD->szTmpDBFile) < 0) {
 		CheckRemoveFile(pDSD->szTmpDBFile);
 		SysFree(pDSD);
-		return (INVALID_ADOMAIN_HANDLE);
+		return INVALID_ADOMAIN_HANDLE;
 	}
-
 	if ((pDSD->pDBFile = fopen(pDSD->szTmpDBFile, "rt")) == NULL) {
 		SysRemove(pDSD->szTmpDBFile);
 		SysFree(pDSD);
-		return (INVALID_ADOMAIN_HANDLE);
+		return INVALID_ADOMAIN_HANDLE;
 	}
 
 	pDSD->ppszStrings = NULL;
 
-	return ((ADOMAIN_HANDLE) pDSD);
-
+	return (ADOMAIN_HANDLE) pDSD;
 }
 
 void ADomCloseDB(ADOMAIN_HANDLE hDomainsDB)
 {
-
 	ADomainScanData *pDSD = (ADomainScanData *) hDomainsDB;
 
 	fclose(pDSD->pDBFile);
-
 	SysRemove(pDSD->szTmpDBFile);
-
 	if (pDSD->ppszStrings != NULL)
 		StrFreeStrings(pDSD->ppszStrings);
-
 	SysFree(pDSD);
-
 }
 
 char const *const *ADomGetFirstDomain(ADOMAIN_HANDLE hDomainsDB)
 {
-
 	ADomainScanData *pDSD = (ADomainScanData *) hDomainsDB;
 
 	rewind(pDSD->pDBFile);
@@ -591,18 +492,16 @@ char const *const *ADomGetFirstDomain(ADOMAIN_HANDLE hDomainsDB)
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
 		if (iFieldsCount >= adomMax)
-			return (pDSD->ppszStrings = ppszStrings);
+			return pDSD->ppszStrings = ppszStrings;
 
 		StrFreeStrings(ppszStrings);
 	}
 
-	return (NULL);
-
+	return NULL;
 }
 
 char const *const *ADomGetNextDomain(ADOMAIN_HANDLE hDomainsDB)
 {
-
 	ADomainScanData *pDSD = (ADomainScanData *) hDomainsDB;
 
 	if (pDSD->ppszStrings != NULL)
@@ -619,11 +518,11 @@ char const *const *ADomGetNextDomain(ADOMAIN_HANDLE hDomainsDB)
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
 		if (iFieldsCount >= adomMax)
-			return (pDSD->ppszStrings = ppszStrings);
+			return pDSD->ppszStrings = ppszStrings;
 
 		StrFreeStrings(ppszStrings);
 	}
 
-	return (NULL);
-
+	return NULL;
 }
+
