@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,...,2002  Davide Libenzi
+ *  Copyright (C) 1999,..,2004  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,24 +20,31 @@
  *
  */
 
-
-#ifndef _COMMTYPES_H
-#define _COMMTYPES_H
+#ifndef _XMCOMMTYPES_H
+#define _XMCOMMTYPES_H
 
 
+struct FileSection {
+	char szFilePath[SYS_MAX_PATH];
+	SYS_OFF_T llStartOffset;
+	SYS_OFF_T llEndOffset;
+};
 
+struct Datum {
+	char *pData;
+	long lSize;
+};
 
+struct LstDatum {
+	SysListHead LLnk;
+	Datum Data;
+};
 
-struct FileSection
-{
-    char            szFilePath[SYS_MAX_PATH];
-    unsigned long   ulStartOffset;
-    unsigned long   ulEndOffset;
+struct LstNDatum {
+	SysListHead LLnk;
+	Datum Name;
+	Datum Data;
 };
 
 
-
-
-
-
 #endif
