@@ -42,11 +42,11 @@
 
 enum ExtAliasFields {
 	ealRmtDomain = 0,
-	ealRmtName,
-	ealDomain,
-	ealName,
+		ealRmtName,
+		ealDomain,
+		ealName,
 
-	ealMax
+		ealMax
 };
 
 struct ExAlDBScanData {
@@ -61,167 +61,132 @@ static int ExAlWriteAlias(FILE * pAliasFile, ExtAlias * pExtAlias);
 
 static int iIdxExAlias_RmtDomain_RmtName[] = {
 	ealRmtDomain,
-	ealRmtName,
+		ealRmtName,
 
-	INDEX_SEQUENCE_TERMINATOR
+		INDEX_SEQUENCE_TERMINATOR
 };
 
 int ExAlCheckAliasIndexes(void)
 {
-
 	char szAliasFilePath[SYS_MAX_PATH] = "";
 
 	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
 
-///////////////////////////////////////////////////////////////////////////////
-//  Align RmtDomain-RmtName index
-///////////////////////////////////////////////////////////////////////////////
+	/* Align RmtDomain-RmtName index */
 	if (TbixCheckIndex(szAliasFilePath, iIdxExAlias_RmtDomain_RmtName, false) < 0)
-		return (ErrGetErrorCode());
-
-	return (0);
+		return ErrGetErrorCode();
 
+	return 0;
 }
 
 static int ExAlRebuildAliasIndexes(char const *pszAliasFilePath)
 {
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild RmtDomain-RmtName index
-///////////////////////////////////////////////////////////////////////////////
+	/* Rebuild RmtDomain-RmtName index */
 	if (TbixCreateIndex(pszAliasFilePath, iIdxExAlias_RmtDomain_RmtName, false) < 0)
-		return (ErrGetErrorCode());
-
-	return (0);
+		return ErrGetErrorCode();
 
+	return 0;
 }
 
 static char *ExAlGetTableFilePath(char *pszLnkFilePath, int iMaxPath)
 {
-
 	CfgGetRootPath(pszLnkFilePath, iMaxPath);
-
 	StrNCat(pszLnkFilePath, SVR_EXT_ALIAS_FILE, iMaxPath);
 
-	return (pszLnkFilePath);
-
+	return pszLnkFilePath;
 }
 
 static ExtAlias *ExAlGetAliasFromStrings(char **ppszStrings)
 {
-
 	int iFieldsCount = StrStringsCount(ppszStrings);
 
 	if (iFieldsCount < ealMax)
-		return (NULL);
+		return NULL;
 
 	ExtAlias *pExtAlias = (ExtAlias *) SysAlloc(sizeof(ExtAlias));
 
 	if (pExtAlias == NULL)
-		return (NULL);
+		return NULL;
 
 	pExtAlias->pszRmtDomain = SysStrDup(ppszStrings[ealRmtDomain]);
 	pExtAlias->pszRmtName = SysStrDup(ppszStrings[ealRmtName]);
 	pExtAlias->pszDomain = SysStrDup(ppszStrings[ealDomain]);
 	pExtAlias->pszName = SysStrDup(ppszStrings[ealName]);
 
-	return (pExtAlias);
-
+	return pExtAlias;
 }
 
 ExtAlias *ExAlAllocAlias(void)
 {
-
 	ExtAlias *pExtAlias = (ExtAlias *) SysAlloc(sizeof(ExtAlias));
 
 	if (pExtAlias == NULL)
-		return (NULL);
+		return NULL;
 
 	pExtAlias->pszRmtDomain = NULL;
 	pExtAlias->pszRmtName = NULL;
 	pExtAlias->pszDomain = NULL;
 	pExtAlias->pszName = NULL;
 
-	return (pExtAlias);
-
+	return pExtAlias;
 }
 
 void ExAlFreeAlias(ExtAlias * pExtAlias)
 {
-
-	if (pExtAlias->pszDomain != NULL)
-		SysFree(pExtAlias->pszDomain);
-
-	if (pExtAlias->pszName != NULL)
-		SysFree(pExtAlias->pszName);
-
-	if (pExtAlias->pszRmtDomain != NULL)
-		SysFree(pExtAlias->pszRmtDomain);
-
-	if (pExtAlias->pszRmtName != NULL)
-		SysFree(pExtAlias->pszRmtName);
-
+	SysFree(pExtAlias->pszDomain);
+	SysFree(pExtAlias->pszName);
+	SysFree(pExtAlias->pszRmtDomain);
+	SysFree(pExtAlias->pszRmtName);
 	SysFree(pExtAlias);
-
 }
 
 static int ExAlWriteAlias(FILE * pAliasFile, ExtAlias * pExtAlias)
 {
-
-///////////////////////////////////////////////////////////////////////////////
-//  Remote domain
-///////////////////////////////////////////////////////////////////////////////
+	/* Remote domain */
 	char *pszQuoted = StrQuote(pExtAlias->pszRmtDomain, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pAliasFile, "%s\t", pszQuoted);
 
 	SysFree(pszQuoted);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Remote user
-///////////////////////////////////////////////////////////////////////////////
+	/* Remote user */
 	pszQuoted = StrQuote(pExtAlias->pszRmtName, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pAliasFile, "%s\t", pszQuoted);
 
 	SysFree(pszQuoted);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Domain
-///////////////////////////////////////////////////////////////////////////////
+	/* Domain */
 	pszQuoted = StrQuote(pExtAlias->pszDomain, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pAliasFile, "%s\t", pszQuoted);
 
 	SysFree(pszQuoted);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Local user
-///////////////////////////////////////////////////////////////////////////////
+	/* Local user */
 	pszQuoted = StrQuote(pExtAlias->pszName, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pAliasFile, "%s\n", pszQuoted);
 
 	SysFree(pszQuoted);
 
-	return (0);
-
+	return 0;
 }
 
 int ExAlAddAlias(ExtAlias * pExtAlias)
 {
-
 	char szAliasFilePath[SYS_MAX_PATH] = "";
 
 	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
@@ -231,7 +196,7 @@ int ExAlAddAlias(ExtAlias * pExtAlias)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	FILE *pAliasFile = fopen(szAliasFilePath, "r+t");
 
@@ -239,7 +204,7 @@ int ExAlAddAlias(ExtAlias * pExtAlias)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_EXTALIAS_FILE_NOT_FOUND);
-		return (ERR_EXTALIAS_FILE_NOT_FOUND);
+		return ERR_EXTALIAS_FILE_NOT_FOUND;
 	}
 
 	char szAliasLine[ALIAS_TABLE_LINE_MAX] = "";
@@ -252,50 +217,42 @@ int ExAlAddAlias(ExtAlias * pExtAlias)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= ealMax) &&
-		    (stricmp(pExtAlias->pszRmtDomain, ppszStrings[ealRmtDomain]) == 0) &&
-		    (stricmp(pExtAlias->pszRmtName, ppszStrings[ealRmtName]) == 0)) {
+		if (iFieldsCount >= ealMax &&
+		    stricmp(pExtAlias->pszRmtDomain, ppszStrings[ealRmtDomain]) == 0 &&
+		    stricmp(pExtAlias->pszRmtName, ppszStrings[ealRmtName]) == 0) {
 			StrFreeStrings(ppszStrings);
 			fclose(pAliasFile);
 			RLckUnlockEX(hResLock);
 
 			ErrSetErrorCode(ERR_EXTALIAS_EXIST);
-			return (ERR_EXTALIAS_EXIST);
+			return ERR_EXTALIAS_EXIST;
 		}
-
 		StrFreeStrings(ppszStrings);
 	}
-
 	fseek(pAliasFile, 0, SEEK_END);
-
 	if (ExAlWriteAlias(pAliasFile, pExtAlias) < 0) {
 		fclose(pAliasFile);
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_WRITE_EXTALIAS_FILE);
-		return (ERR_WRITE_EXTALIAS_FILE);
+		return ERR_WRITE_EXTALIAS_FILE;
 	}
-
 	fclose(pAliasFile);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild indexes
-///////////////////////////////////////////////////////////////////////////////
+	/* Rebuild indexes */
 	if (ExAlRebuildAliasIndexes(szAliasFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 ExtAlias *ExAlGetAlias(char const *pszRmtDomain, char const *pszRmtName)
 {
-
 	char szAliasFilePath[SYS_MAX_PATH] = "";
 
 	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
@@ -305,11 +262,9 @@ ExtAlias *ExAlGetAlias(char const *pszRmtDomain, char const *pszRmtName)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (NULL);
+		return NULL;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Lookup record using the specified index
-///////////////////////////////////////////////////////////////////////////////
+	/* Lookup record using the specified index */
 	char **ppszTabTokens = TbixLookup(szAliasFilePath, iIdxExAlias_RmtDomain_RmtName, false,
 					  pszRmtDomain,
 					  pszRmtName,
@@ -319,28 +274,23 @@ ExtAlias *ExAlGetAlias(char const *pszRmtDomain, char const *pszRmtName)
 		RLckUnlockSH(hResLock);
 		ErrSetErrorCode(ERR_EXTALIAS_NOT_FOUND);
 
-		return (NULL);
+		return NULL;
 	}
 
 	ExtAlias *pExtAlias = ExAlGetAliasFromStrings(ppszTabTokens);
 
 	StrFreeStrings(ppszTabTokens);
-
 	RLckUnlockSH(hResLock);
 
-	return (pExtAlias);
-
+	return pExtAlias;
 }
 
 int ExAlRemoveAlias(ExtAlias * pExtAlias)
 {
-
 	char szAliasFilePath[SYS_MAX_PATH] = "";
-
-	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
-
 	char szTmpFile[SYS_MAX_PATH] = "";
 
+	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
 	SysGetTmpFile(szTmpFile);
 
 	char szResLock[SYS_MAX_PATH] = "";
@@ -348,7 +298,7 @@ int ExAlRemoveAlias(ExtAlias * pExtAlias)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	FILE *pAliasFile = fopen(szAliasFilePath, "rt");
 
@@ -356,7 +306,7 @@ int ExAlRemoveAlias(ExtAlias * pExtAlias)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_EXTALIAS_FILE_NOT_FOUND);
-		return (ERR_EXTALIAS_FILE_NOT_FOUND);
+		return ERR_EXTALIAS_FILE_NOT_FOUND;
 	}
 
 	FILE *pTmpFile = fopen(szTmpFile, "wt");
@@ -366,7 +316,7 @@ int ExAlRemoveAlias(ExtAlias * pExtAlias)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_FILE_CREATE);
-		return (ERR_FILE_CREATE);
+		return ERR_FILE_CREATE;
 	}
 
 	int iAliasFound = 0;
@@ -380,18 +330,14 @@ int ExAlRemoveAlias(ExtAlias * pExtAlias)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= ealMax) &&
-		    (stricmp(pExtAlias->pszRmtDomain, ppszStrings[ealRmtDomain]) == 0) &&
-		    (stricmp(pExtAlias->pszRmtName, ppszStrings[ealRmtName]) == 0)) {
-
+		if (iFieldsCount >= ealMax &&
+		    stricmp(pExtAlias->pszRmtDomain, ppszStrings[ealRmtDomain]) == 0 &&
+		    stricmp(pExtAlias->pszRmtName, ppszStrings[ealRmtName]) == 0) {
 			++iAliasFound;
-
 		} else
 			fprintf(pTmpFile, "%s\n", szAliasLine);
-
 		StrFreeStrings(ppszStrings);
 	}
-
 	fclose(pAliasFile);
 	fclose(pTmpFile);
 
@@ -400,51 +346,30 @@ int ExAlRemoveAlias(ExtAlias * pExtAlias)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_EXTALIAS_NOT_FOUND);
-		return (ERR_EXTALIAS_NOT_FOUND);
+		return ERR_EXTALIAS_NOT_FOUND;
 	}
-
-	char szTmpAliasFilePath[SYS_MAX_PATH] = "";
-
-	SysSNPrintf(szTmpAliasFilePath, sizeof(szTmpAliasFilePath) - 1, "%s.tmp",
-		    szAliasFilePath);
-
-	if (MscMoveFile(szAliasFilePath, szTmpAliasFilePath) < 0) {
-		RLckUnlockEX(hResLock);
-		return (ErrGetErrorCode());
-	}
-
 	if (MscMoveFile(szTmpFile, szAliasFilePath) < 0) {
-		MscMoveFile(szTmpAliasFilePath, szAliasFilePath);
 		RLckUnlockEX(hResLock);
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 	}
 
-	SysRemove(szTmpAliasFilePath);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild indexes
-///////////////////////////////////////////////////////////////////////////////
+	/* Rebuild indexes */
 	if (ExAlRebuildAliasIndexes(szAliasFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
-
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 int ExAlRemoveUserAliases(const char *pszDomain, const char *pszName)
 {
-
 	char szAliasFilePath[SYS_MAX_PATH] = "";
-
-	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
-
 	char szTmpFile[SYS_MAX_PATH] = "";
 
+	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
 	SysGetTmpFile(szTmpFile);
 
 	char szResLock[SYS_MAX_PATH] = "";
@@ -454,7 +379,7 @@ int ExAlRemoveUserAliases(const char *pszDomain, const char *pszName)
 	if (hResLock == INVALID_RLCK_HANDLE) {
 		ErrorPush();
 		CheckRemoveFile(szTmpFile);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
 	FILE *pAliasFile = fopen(szAliasFilePath, "rt");
@@ -464,7 +389,7 @@ int ExAlRemoveUserAliases(const char *pszDomain, const char *pszName)
 		CheckRemoveFile(szTmpFile);
 
 		ErrSetErrorCode(ERR_EXTALIAS_FILE_NOT_FOUND);
-		return (ERR_EXTALIAS_FILE_NOT_FOUND);
+		return ERR_EXTALIAS_FILE_NOT_FOUND;
 	}
 
 	FILE *pTmpFile = fopen(szTmpFile, "wt");
@@ -475,7 +400,7 @@ int ExAlRemoveUserAliases(const char *pszDomain, const char *pszName)
 		CheckRemoveFile(szTmpFile);
 
 		ErrSetErrorCode(ERR_FILE_CREATE);
-		return (ERR_FILE_CREATE);
+		return ERR_FILE_CREATE;
 	}
 
 	int iAliasFound = 0;
@@ -489,70 +414,44 @@ int ExAlRemoveUserAliases(const char *pszDomain, const char *pszName)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= ealMax) && (stricmp(pszDomain, ppszStrings[ealDomain]) == 0)
-		    && (stricmp(pszName, ppszStrings[ealName]) == 0)) {
-
+		if (iFieldsCount >= ealMax && stricmp(pszDomain, ppszStrings[ealDomain]) == 0 &&
+		    stricmp(pszName, ppszStrings[ealName]) == 0) {
 			++iAliasFound;
-
 		} else
 			fprintf(pTmpFile, "%s\n", szAliasLine);
-
 		StrFreeStrings(ppszStrings);
 	}
-
 	fclose(pAliasFile);
 	fclose(pTmpFile);
 
 	if (iAliasFound == 0) {
 		SysRemove(szTmpFile);
 		RLckUnlockEX(hResLock);
-		return (0);
+		return 0;
 	}
-
-	char szTmpAliasFilePath[SYS_MAX_PATH] = "";
-
-	SysSNPrintf(szTmpAliasFilePath, sizeof(szTmpAliasFilePath) - 1, "%s.tmp",
-		    szAliasFilePath);
-
-	if (MscMoveFile(szAliasFilePath, szTmpAliasFilePath) < 0) {
-		ErrorPush();
-		RLckUnlockEX(hResLock);
-		return (ErrorPop());
-	}
-
 	if (MscMoveFile(szTmpFile, szAliasFilePath) < 0) {
 		ErrorPush();
-		MscMoveFile(szTmpAliasFilePath, szAliasFilePath);
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
-	SysRemove(szTmpAliasFilePath);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild indexes
-///////////////////////////////////////////////////////////////////////////////
+	/* Rebuild indexes */
 	if (ExAlRebuildAliasIndexes(szAliasFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
-
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 int ExAlRemoveDomainAliases(const char *pszDomain)
 {
-
 	char szAliasFilePath[SYS_MAX_PATH] = "";
-
-	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
-
 	char szTmpFile[SYS_MAX_PATH] = "";
 
+	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
 	SysGetTmpFile(szTmpFile);
 
 	char szResLock[SYS_MAX_PATH] = "";
@@ -562,7 +461,7 @@ int ExAlRemoveDomainAliases(const char *pszDomain)
 	if (hResLock == INVALID_RLCK_HANDLE) {
 		ErrorPush();
 		CheckRemoveFile(szTmpFile);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
 	FILE *pAliasFile = fopen(szAliasFilePath, "rt");
@@ -572,7 +471,7 @@ int ExAlRemoveDomainAliases(const char *pszDomain)
 		CheckRemoveFile(szTmpFile);
 
 		ErrSetErrorCode(ERR_EXTALIAS_FILE_NOT_FOUND);
-		return (ERR_EXTALIAS_FILE_NOT_FOUND);
+		return ERR_EXTALIAS_FILE_NOT_FOUND;
 	}
 
 	FILE *pTmpFile = fopen(szTmpFile, "wt");
@@ -583,7 +482,7 @@ int ExAlRemoveDomainAliases(const char *pszDomain)
 		CheckRemoveFile(szTmpFile);
 
 		ErrSetErrorCode(ERR_FILE_CREATE);
-		return (ERR_FILE_CREATE);
+		return ERR_FILE_CREATE;
 	}
 
 	int iAliasFound = 0;
@@ -597,65 +496,40 @@ int ExAlRemoveDomainAliases(const char *pszDomain)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= ealMax) && (stricmp(pszDomain, ppszStrings[ealDomain]) == 0)) {
+		if (iFieldsCount >= ealMax && stricmp(pszDomain, ppszStrings[ealDomain]) == 0) {
 
 			++iAliasFound;
-
 		} else
 			fprintf(pTmpFile, "%s\n", szAliasLine);
-
 		StrFreeStrings(ppszStrings);
 	}
-
 	fclose(pAliasFile);
 	fclose(pTmpFile);
 
 	if (iAliasFound == 0) {
 		SysRemove(szTmpFile);
 		RLckUnlockEX(hResLock);
-		return (0);
+		return 0;
 	}
-
-	char szTmpAliasFilePath[SYS_MAX_PATH] = "";
-
-	SysSNPrintf(szTmpAliasFilePath, sizeof(szTmpAliasFilePath) - 1, "%s.tmp",
-		    szAliasFilePath);
-
-	if (MscMoveFile(szAliasFilePath, szTmpAliasFilePath) < 0) {
-		ErrorPush();
-		SysRemove(szTmpFile);
-		RLckUnlockEX(hResLock);
-		return (ErrorPop());
-	}
-
 	if (MscMoveFile(szTmpFile, szAliasFilePath) < 0) {
 		ErrorPush();
-		MscMoveFile(szTmpAliasFilePath, szAliasFilePath);
-		SysRemove(szTmpFile);
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
-	SysRemove(szTmpAliasFilePath);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild indexes
-///////////////////////////////////////////////////////////////////////////////
+	/* Rebuild indexes */
 	if (ExAlRebuildAliasIndexes(szAliasFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
-
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 int ExAlGetDBFileSnapShot(const char *pszFileName)
 {
-
 	char szAliasFilePath[SYS_MAX_PATH] = "";
 
 	ExAlGetTableFilePath(szAliasFilePath, sizeof(szAliasFilePath));
@@ -665,60 +539,50 @@ int ExAlGetDBFileSnapShot(const char *pszFileName)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	if (MscCopyFile(pszFileName, szAliasFilePath) < 0) {
 		RLckUnlockSH(hResLock);
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 	}
 
 	RLckUnlockSH(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 EXAL_HANDLE ExAlOpenDB(void)
 {
-
 	ExAlDBScanData *pGLSD = (ExAlDBScanData *) SysAlloc(sizeof(ExAlDBScanData));
 
 	if (pGLSD == NULL)
-		return (INVALID_EXAL_HANDLE);
+		return INVALID_EXAL_HANDLE;
 
 	SysGetTmpFile(pGLSD->szTmpDBFile);
-
 	if (ExAlGetDBFileSnapShot(pGLSD->szTmpDBFile) < 0) {
 		SysFree(pGLSD);
-		return (INVALID_EXAL_HANDLE);
+		return INVALID_EXAL_HANDLE;
 	}
-
 	if ((pGLSD->pDBFile = fopen(pGLSD->szTmpDBFile, "rt")) == NULL) {
 		SysRemove(pGLSD->szTmpDBFile);
 		SysFree(pGLSD);
-		return (INVALID_EXAL_HANDLE);
+		return INVALID_EXAL_HANDLE;
 	}
 
-	return ((EXAL_HANDLE) pGLSD);
-
+	return (EXAL_HANDLE) pGLSD;
 }
 
 void ExAlCloseDB(EXAL_HANDLE hLinksDB)
 {
-
 	ExAlDBScanData *pGLSD = (ExAlDBScanData *) hLinksDB;
 
 	fclose(pGLSD->pDBFile);
-
 	SysRemove(pGLSD->szTmpDBFile);
-
 	SysFree(pGLSD);
-
 }
 
 ExtAlias *ExAlGetFirstAlias(EXAL_HANDLE hLinksDB)
 {
-
 	ExAlDBScanData *pGLSD = (ExAlDBScanData *) hLinksDB;
 
 	rewind(pGLSD->pDBFile);
@@ -726,8 +590,8 @@ ExtAlias *ExAlGetFirstAlias(EXAL_HANDLE hLinksDB)
 	ExtAlias *pExtAlias = NULL;
 	char szAliasLine[ALIAS_TABLE_LINE_MAX] = "";
 
-	while ((pExtAlias == NULL) &&
-	       (MscFGets(szAliasLine, sizeof(szAliasLine) - 1, pGLSD->pDBFile) != NULL)) {
+	while (pExtAlias == NULL &&
+	       MscFGets(szAliasLine, sizeof(szAliasLine) - 1, pGLSD->pDBFile) != NULL) {
 		char **ppszStrings = StrGetTabLineStrings(szAliasLine);
 
 		if (ppszStrings == NULL)
@@ -741,20 +605,18 @@ ExtAlias *ExAlGetFirstAlias(EXAL_HANDLE hLinksDB)
 		StrFreeStrings(ppszStrings);
 	}
 
-	return (pExtAlias);
-
+	return pExtAlias;
 }
 
 ExtAlias *ExAlGetNextAlias(EXAL_HANDLE hLinksDB)
 {
-
 	ExAlDBScanData *pGLSD = (ExAlDBScanData *) hLinksDB;
 
 	ExtAlias *pExtAlias = NULL;
 	char szAliasLine[ALIAS_TABLE_LINE_MAX] = "";
 
-	while ((pExtAlias == NULL) &&
-	       (MscFGets(szAliasLine, sizeof(szAliasLine) - 1, pGLSD->pDBFile) != NULL)) {
+	while (pExtAlias == NULL &&
+	       MscFGets(szAliasLine, sizeof(szAliasLine) - 1, pGLSD->pDBFile) != NULL) {
 		char **ppszStrings = StrGetTabLineStrings(szAliasLine);
 
 		if (ppszStrings == NULL)
@@ -768,6 +630,6 @@ ExtAlias *ExAlGetNextAlias(EXAL_HANDLE hLinksDB)
 		StrFreeStrings(ppszStrings);
 	}
 
-	return (pExtAlias);
-
+	return pExtAlias;
 }
+
