@@ -26,6 +26,8 @@
 #include "ShBlocks.h"
 #include "SList.h"
 #include "BuffSock.h"
+#include "SSLBind.h"
+#include "SSLConfig.h"
 #include "StrUtils.h"
 #include "ResLocks.h"
 #include "MiscUtils.h"
@@ -40,21 +42,15 @@
 #include "MailSvr.h"
 #include "FINGSvr.h"
 
-#define FINGSRV_ACCEPT_TIMEOUT  4
-#define FING_LISTEN_SIZE        64
-#define FING_WAIT_SLEEP         2
-#define MAX_CLIENTS_WAIT        300
 #define FING_IPMAP_FILE         "finger.ipmap.tab"
 #define FING_LOG_FILE           "finger"
-#define FING_SERVER_NAME        "[" APP_NAME_VERSION_STR " FINGER Server]"
 
 static int FINGCheckPeerIP(SYS_SOCKET SockFD);
 static FINGConfig *FINGGetConfigCopy(SHB_HANDLE hShbFING);
 static int FINGLogEnabled(SHB_HANDLE hShbFING, FINGConfig * pFINGCfg = NULL);
-static unsigned int FINGClientThread(void *pThreadData);
 static int FINGLogSession(char const *pszSockHost, char const *pszSockDomain,
 			  SYS_INET_ADDR & PeerInfo, char const *pszQuery);
-static int FINGHandleSession(SHB_HANDLE hShbFING, BSOCK_HANDLE hBSock);
+static int FINGHandleSession(ThreadConfig const *pThCfg, BSOCK_HANDLE hBSock);
 static int FINGProcessQuery(char const *pszQuery, BSOCK_HANDLE hBSock,
 			    FINGConfig * pFINGCfg, char const *pszSockDomain,
 			    SVRCFG_HANDLE hSvrConfig);
@@ -64,7 +60,6 @@ static int FINGDumpMailingList(UserInfo * pUI, BSOCK_HANDLE hBSock, FINGConfig *
 
 static int FINGCheckPeerIP(SYS_SOCKET SockFD)
 {
-
 	char szIPMapFile[SYS_MAX_PATH] = "";
 
 	CfgGetRootPath(szIPMapFile, sizeof(szIPMapFile));
@@ -74,23 +69,21 @@ static int FINGCheckPeerIP(SYS_SOCKET SockFD)
 		SYS_INET_ADDR PeerInfo;
 
 		if (SysGetPeerInfo(SockFD, PeerInfo) < 0)
-			return (ErrGetErrorCode());
+			return ErrGetErrorCode();
 
 		if (MscCheckAllowedIP(szIPMapFile, PeerInfo, true) < 0)
-			return (ErrGetErrorCode());
+			return ErrGetErrorCode();
 	}
 
-	return (0);
-
+	return 0;
 }
 
 static FINGConfig *FINGGetConfigCopy(SHB_HANDLE hShbFING)
 {
-
 	FINGConfig *pFINGCfg = (FINGConfig *) ShbLock(hShbFING);
 
 	if (pFINGCfg == NULL)
-		return (NULL);
+		return NULL;
 
 	FINGConfig *pFINGCfgCopy = (FINGConfig *) SysAlloc(sizeof(FINGConfig));
 
@@ -99,19 +92,16 @@ static FINGConfig *FINGGetConfigCopy(SHB_HANDLE hShbFING)
 
 	ShbUnlock(hShbFING);
 
-	return (pFINGCfgCopy);
-
+	return pFINGCfgCopy;
 }
 
 static int FINGLogEnabled(SHB_HANDLE hShbFING, FINGConfig * pFINGCfg)
 {
-
 	int iDoUnlock = 0;
 
 	if (pFINGCfg == NULL) {
 		if ((pFINGCfg = (FINGConfig *) ShbLock(hShbFING)) == NULL)
-			return (ErrGetErrorCode());
-
+			return ErrGetErrorCode();
 		++iDoUnlock;
 	}
 
@@ -120,172 +110,101 @@ static int FINGLogEnabled(SHB_HANDLE hShbFING, FINGConfig * pFINGCfg)
 	if (iDoUnlock)
 		ShbUnlock(hShbFING);
 
-	return ((ulFlags & FINGF_LOG_ENABLED) ? 1 : 0);
-
+	return (ulFlags & FINGF_LOG_ENABLED) ? 1 : 0;
 }
 
-static unsigned int FINGClientThread(void *pThreadData)
+unsigned int FINGClientThread(void *pThreadData)
 {
+	ThreadCreateCtx *pThCtx = (ThreadCreateCtx *) pThreadData;
 
-	SYS_SOCKET SockFD = (SYS_SOCKET) (unsigned long) pThreadData;
-
-///////////////////////////////////////////////////////////////////////////////
-//  Check peer IP address serivce access permissions
-///////////////////////////////////////////////////////////////////////////////
-	if (FINGCheckPeerIP(SockFD) < 0) {
+	/* Check IP permission */
+	if (FINGCheckPeerIP(pThCtx->SockFD) < 0) {
 		ErrorPush();
 		SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-		SysCloseSocket(SockFD);
-		return (ErrorPop());
-	}
-///////////////////////////////////////////////////////////////////////////////
-//  Increase threads count
-///////////////////////////////////////////////////////////////////////////////
-	FINGConfig *pFINGCfg = (FINGConfig *) ShbLock(hShbFING);
-
-	if (pFINGCfg == NULL) {
-		ErrorPush();
-		SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-		SysCloseSocket(SockFD);
-		return (ErrorPop());
+		SysCloseSocket(pThCtx->SockFD);
+		SysFree(pThCtx);
+		return ErrorPop();
 	}
 
-	++pFINGCfg->lThreadCount;
-
-	ShbUnlock(hShbFING);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Link socket to the bufferer
-///////////////////////////////////////////////////////////////////////////////
-	BSOCK_HANDLE hBSock = BSckAttach(SockFD);
+	/* Link socket to the bufferer */
+	BSOCK_HANDLE hBSock = BSckAttach(pThCtx->SockFD);
 
 	if (hBSock == INVALID_BSOCK_HANDLE) {
 		ErrorPush();
-		SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-		SysCloseSocket(SockFD);
-		return (ErrorPop());
+		SysCloseSocket(pThCtx->SockFD);
+		SysFree(pThCtx);
+		return ErrorPop();
 	}
 
-///////////////////////////////////////////////////////////////////////////////
-//  Handle client session
-///////////////////////////////////////////////////////////////////////////////
-	FINGHandleSession(hShbFING, hBSock);
+	/*
+	 * Do we need to switch to TLS?
+	 */
+	if (pThCtx->pThCfg->ulFlags & THCF_USE_SSL) {
+		int iError;
+		SslServerBind SSLB;
+		SslBindEnv SslE;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Unlink socket to the bufferer and close it
-///////////////////////////////////////////////////////////////////////////////
-	BSckDetach(hBSock, 1);
+		if (CSslBindSetup(&SSLB) < 0) {
+			ErrorPush();
+			BSckDetach(hBSock, 1);
+			SysFree(pThCtx);
+			return ErrorPop();
+		}
+		ZeroData(SslE);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Decrease thread count
-///////////////////////////////////////////////////////////////////////////////
-	pFINGCfg = (FINGConfig *) ShbLock(hShbFING);
+		iError = BSslBindServer(hBSock, &SSLB, MscSslEnvCB, &SslE);
+
+		CSslBindCleanup(&SSLB);
+		if (iError < 0) {
+			ErrorPush();
+			BSckDetach(hBSock, 1);
+			SysFree(pThCtx);
+			return ErrorPop();
+		}
+		/*
+		 * We may want to add verify code here ...
+		 */
+
+		SysFree(SslE.pszIssuer);
+		SysFree(SslE.pszSubject);
+	}
+	/* Increase threads count */
+	FINGConfig *pFINGCfg = (FINGConfig *) ShbLock(pThCtx->pThCfg->hThShb);
 
 	if (pFINGCfg == NULL) {
 		ErrorPush();
 		SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-		return (ErrorPop());
+		BSckDetach(hBSock, 1);
+		SysFree(pThCtx);
+		return ErrorPop();
 	}
+	++pFINGCfg->lThreadCount;
+	ShbUnlock(pThCtx->pThCfg->hThShb);
 
+	/* Handle client session */
+	FINGHandleSession(pThCtx->pThCfg, hBSock);
+
+	/* Decrease threads count */
+	pFINGCfg = (FINGConfig *) ShbLock(pThCtx->pThCfg->hThShb);
+
+	if (pFINGCfg == NULL) {
+		ErrorPush();
+		SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
+		return ErrorPop();
+	}
 	--pFINGCfg->lThreadCount;
+	ShbUnlock(pThCtx->pThCfg->hThShb);
 
-	ShbUnlock(hShbFING);
-
-	return (0);
-
-}
-
-unsigned int FINGThreadProc(void *pThreadData)
-{
-
-	FINGConfig *pFINGCfg = (FINGConfig *) ShbLock(hShbFING);
-
-	if (pFINGCfg == NULL) {
-		ErrorPush();
-		SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-		return (ErrorPop());
-	}
-
-	int iNumSockFDs = 0;
-	SYS_SOCKET SockFDs[MAX_FING_ACCEPT_ADDRESSES];
-
-	if (MscCreateServerSockets(pFINGCfg->iNumAddr, pFINGCfg->SvrAddr, pFINGCfg->iPort,
-				   FING_LISTEN_SIZE, SockFDs, iNumSockFDs) < 0) {
-		ErrorPush();
-		SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString());
-		ShbUnlock(hShbFING);
-		return (ErrorPop());
-	}
-
-	ShbUnlock(hShbFING);
-
-	SysLogMessage(LOG_LEV_MESSAGE, "%s started\n", FING_SERVER_NAME);
-
-	for (;;) {
-		int iNumConnSockFD = 0;
-		SYS_SOCKET ConnSockFD[MAX_FING_ACCEPT_ADDRESSES];
-
-		if (MscAcceptServerConnection(SockFDs, iNumSockFDs, ConnSockFD,
-					      iNumConnSockFD, FINGSRV_ACCEPT_TIMEOUT) < 0) {
-			unsigned long ulFlags = FINGF_STOP_SERVER;
-
-			pFINGCfg = (FINGConfig *) ShbLock(hShbFING);
-
-			if (pFINGCfg != NULL)
-				ulFlags = pFINGCfg->ulFlags;
-
-			ShbUnlock(hShbFING);
-
-			if (ulFlags & FINGF_STOP_SERVER)
-				break;
-			else
-				continue;
-		}
-
-		for (int ss = 0; ss < iNumConnSockFD; ss++) {
-			SYS_THREAD hClientThread =
-			    SysCreateServiceThread(FINGClientThread, ConnSockFD[ss]);
-
-			if (hClientThread != SYS_INVALID_THREAD)
-				SysCloseThread(hClientThread, 0);
-			else
-				SysCloseSocket(ConnSockFD[ss]);
-
-		}
-	}
-
-	for (int ss = 0; ss < iNumSockFDs; ss++)
-		SysCloseSocket(SockFDs[ss]);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Wait for clients completion
-///////////////////////////////////////////////////////////////////////////////
-	for (int iTotalWait = 0; (iTotalWait < MAX_CLIENTS_WAIT); iTotalWait += FING_WAIT_SLEEP) {
-		pFINGCfg = (FINGConfig *) ShbLock(hShbFING);
-
-		if (pFINGCfg == NULL)
-			break;
-
-		long lThreadCount = pFINGCfg->lThreadCount;
-
-		ShbUnlock(hShbFING);
-
-		if (lThreadCount == 0)
-			break;
-
-		SysSleep(FING_WAIT_SLEEP);
-	}
-
-	SysLogMessage(LOG_LEV_MESSAGE, "%s stopped\n", FING_SERVER_NAME);
-
-	return (0);
+	/* Unlink socket from the bufferer and close it */
+	BSckDetach(hBSock, 1);
+	SysFree(pThCtx);
 
+	return 0;
 }
 
 static int FINGLogSession(char const *pszSockHost, char const *pszSockDomain,
 			  SYS_INET_ADDR & PeerInfo, char const *pszQuery)
 {
-
 	char szTime[256] = "";
 
 	MscGetTimeNbrString(szTime, sizeof(szTime) - 1);
@@ -293,7 +212,7 @@ static int FINGLogSession(char const *pszSockHost, char const *pszSockDomain,
 	RLCK_HANDLE hResLock = RLckLockEX(SVR_LOGS_DIR SYS_SLASH_STR FING_LOG_FILE);
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	char szIP[128] = "???.???.???.???";
 
@@ -302,23 +221,19 @@ static int FINGLogSession(char const *pszSockHost, char const *pszSockDomain,
 		   "\t\"%s\""
 		   "\t\"%s\""
 		   "\t\"%s\""
-		   "\n", pszSockHost, pszSockDomain, SysInetNToA(PeerInfo, szIP),
+		   "\n", pszSockHost, pszSockDomain, SysInetNToA(PeerInfo, szIP, sizeof(szIP)),
 		   szTime, pszQuery);
 
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
-static int FINGHandleSession(SHB_HANDLE hShbFING, BSOCK_HANDLE hBSock)
+static int FINGHandleSession(ThreadConfig const *pThCfg, BSOCK_HANDLE hBSock)
 {
+	FINGConfig *pFINGCfg = FINGGetConfigCopy(pThCfg->hThShb);
 
-	FINGConfig *pFINGCfg = FINGGetConfigCopy(hShbFING);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Get client socket info
-///////////////////////////////////////////////////////////////////////////////
+	/* Get client socket info */
 	SYS_INET_ADDR PeerInfo;
 
 	if (SysGetPeerInfo(BSckGetAttachedSocket(hBSock), PeerInfo) < 0) {
@@ -327,45 +242,43 @@ static int FINGHandleSession(SHB_HANDLE hShbFING, BSOCK_HANDLE hBSock)
 		SysFree(pFINGCfg);
 
 		SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString(ErrorFetch()));
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
-///////////////////////////////////////////////////////////////////////////////
-//  Get server socket FQDN
-///////////////////////////////////////////////////////////////////////////////
+	/* Get server socket FQDN */
 	char szSvrFQDN[MAX_HOST_NAME] = "";
 
-	if (MscGetSockHost(BSckGetAttachedSocket(hBSock), szSvrFQDN) < 0) {
+	if (MscGetSockHost(BSckGetAttachedSocket(hBSock), szSvrFQDN,
+			   sizeof(szSvrFQDN)) < 0) {
 		ErrorPush();
 		BSckSendString(hBSock, ErrGetErrorString(ErrorFetch()), pFINGCfg->iTimeout);
 		SysFree(pFINGCfg);
 
 		SysLogMessage(LOG_LEV_ERROR, "%s\n", ErrGetErrorString(ErrorFetch()));
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
 	char szSockHost[MAX_HOST_NAME] = "";
 	char szSockDomain[MAX_HOST_NAME] = "";
 
-	MscSplitFQDN(szSvrFQDN, szSockHost, szSockDomain);
+	MscSplitFQDN(szSvrFQDN, szSockHost, sizeof(szSockHost),
+		     szSockDomain, sizeof(szSockDomain));
 
 	char szIP[128] = "???.???.???.???";
 
 	SysLogMessage(LOG_LEV_MESSAGE, "FINGER client connection from [%s]\n",
-		      SysInetNToA(PeerInfo, szIP));
+		      SysInetNToA(PeerInfo, szIP, sizeof(szIP)));
 
 	char szQuery[1024] = "";
 
-	if ((BSckGetString(hBSock, szQuery, sizeof(szQuery) - 1, pFINGCfg->iTimeout) != NULL) &&
-	    (MscCmdStringCheck(szQuery) == 0)) {
-///////////////////////////////////////////////////////////////////////////////
-//  Log FINGER question
-///////////////////////////////////////////////////////////////////////////////
+	if (BSckGetString(hBSock, szQuery, sizeof(szQuery) - 1, pFINGCfg->iTimeout) != NULL &&
+	    MscCmdStringCheck(szQuery) == 0) {
+		/* Log FINGER question */
 		if (FINGLogEnabled(hShbFING))
 			FINGLogSession(szSockHost, szSockDomain, PeerInfo, szQuery);
 
 		SysLogMessage(LOG_LEV_MESSAGE, "FINGER query [%s] : \"%s\"\n",
-			      SysInetNToA(PeerInfo, szIP), szQuery);
+			      SysInetNToA(PeerInfo, szIP, sizeof(szIP)), szQuery);
 
 		SVRCFG_HANDLE hSvrConfig = SvrGetConfigHandle();
 
@@ -374,23 +287,19 @@ static int FINGHandleSession(SHB_HANDLE hShbFING, BSOCK_HANDLE hBSock)
 		if (hSvrConfig != INVALID_SVRCFG_HANDLE)
 			SvrReleaseConfigHandle(hSvrConfig);
 	}
-
 	SysFree(pFINGCfg);
 
-	SysLogMessage(LOG_LEV_MESSAGE, "FINGER client exit [%s]\n", SysInetNToA(PeerInfo, szIP));
-
-	return (0);
+	SysLogMessage(LOG_LEV_MESSAGE, "FINGER client exit [%s]\n",
+		      SysInetNToA(PeerInfo, szIP, sizeof(szIP)));
 
+	return 0;
 }
 
 static int FINGProcessQuery(char const *pszQuery, BSOCK_HANDLE hBSock,
 			    FINGConfig * pFINGCfg, char const *pszSockDomain,
 			    SVRCFG_HANDLE hSvrConfig)
 {
-
-///////////////////////////////////////////////////////////////////////////////
-//  Check for verbose query
-///////////////////////////////////////////////////////////////////////////////
+	/* Check for verbose query */
 	int iVerbose = 0;
 
 	if (pszQuery[0] == '/') {
@@ -398,26 +307,22 @@ static int FINGProcessQuery(char const *pszQuery, BSOCK_HANDLE hBSock,
 			BSckSendString(hBSock, "Invalid query", pFINGCfg->iTimeout);
 
 			ErrSetErrorCode(ERR_FINGER_QUERY_FORMAT);
-			return (ERR_FINGER_QUERY_FORMAT);
+			return ERR_FINGER_QUERY_FORMAT;
 		}
 
 		++iVerbose;
 		pszQuery += 2;
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  Discard spaces
-///////////////////////////////////////////////////////////////////////////////
+	/* Discard spaces */
 	for (; *pszQuery == ' '; pszQuery++);
 
 	if (*pszQuery == '\0') {
 		BSckSendString(hBSock, "Empty query not allowed", pFINGCfg->iTimeout);
 
 		ErrSetErrorCode(ERR_FINGER_QUERY_FORMAT);
-		return (ERR_FINGER_QUERY_FORMAT);
+		return ERR_FINGER_QUERY_FORMAT;
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  Split user-domain
-///////////////////////////////////////////////////////////////////////////////
+	/* Split user-domain */
 	char szUser[MAX_ADDR_NAME] = "";
 	char szDomain[MAX_ADDR_NAME] = "";
 
@@ -427,23 +332,19 @@ static int FINGProcessQuery(char const *pszQuery, BSOCK_HANDLE hBSock,
 
 			BSckSendString(hBSock, "Invalid query", pFINGCfg->iTimeout);
 
-			return (ErrorPop());
+			return ErrorPop();
 		}
 	} else
 		StrSNCpy(szUser, pszQuery);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Check if indirect query
-///////////////////////////////////////////////////////////////////////////////
+	/* Check if indirect query */
 	if (strchr(szDomain, '@') != NULL) {
 		BSckSendString(hBSock, "Indirect query not allowed", pFINGCfg->iTimeout);
 
 		ErrSetErrorCode(ERR_FINGER_QUERY_FORMAT);
-		return (ERR_FINGER_QUERY_FORMAT);
+		return ERR_FINGER_QUERY_FORMAT;
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  Setup domain name in case of username only query
-///////////////////////////////////////////////////////////////////////////////
+	/* Setup domain name in case of username only query */
 	if (IsEmptyString(szDomain)) {
 		if (SvrConfigVar("POP3Domain", szDomain, sizeof(szDomain), hSvrConfig) < 0) {
 			if (strlen(pszSockDomain) == 0) {
@@ -454,90 +355,72 @@ static int FINGProcessQuery(char const *pszQuery, BSOCK_HANDLE hBSock,
 					BSckSendString(hBSock, "User not found",
 						       pFINGCfg->iTimeout);
 
-					return (ErrorPop());
+					return ErrorPop();
 				}
 			} else
 				StrSNCpy(szDomain, pszSockDomain);
 		}
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  Dump user
-///////////////////////////////////////////////////////////////////////////////
+	/* Dump user */
 	if (FINGDumpUser(szUser, szDomain, hBSock, pFINGCfg) < 0) {
 		ErrorPush();
 
 		BSckSendString(hBSock, "User not found", pFINGCfg->iTimeout);
 
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
-	return (0);
-
+	return 0;
 }
 
 static int FINGDumpUser(char const *pszUser, char const *pszDomain,
 			BSOCK_HANDLE hBSock, FINGConfig * pFINGCfg)
 {
-
-///////////////////////////////////////////////////////////////////////////////
-//  Lookup user
-///////////////////////////////////////////////////////////////////////////////
+	/* Lookup user */
 	char szRealAddr[MAX_ADDR_NAME] = "";
 	UserInfo *pUI = UsrGetUserByNameOrAlias(pszDomain, pszUser, szRealAddr);
 
 	if (pUI != NULL) {
 		if (UsrGetUserType(pUI) == usrTypeUser) {
-///////////////////////////////////////////////////////////////////////////////
-//  Local user case
-///////////////////////////////////////////////////////////////////////////////
+			/* Local user case */
 			char *pszRealName = UsrGetUserInfoVar(pUI, "RealName");
 			char *pszHomePage = UsrGetUserInfoVar(pUI, "HomePage");
 			char szRespBuffer[2048] = "";
 
-			sprintf(szRespBuffer,
-				"EMail       : %s\r\n"
-				"  Real Name : %s\r\n"
-				"  Home Page : %s",
-				szRealAddr,
-				(pszRealName != NULL) ? pszRealName : "??",
-				(pszHomePage != NULL) ? pszHomePage : "??");
+			SysSNPrintf(szRespBuffer, sizeof(szRespBuffer),
+				    "EMail       : %s\r\n"
+				    "  Real Name : %s\r\n"
+				    "  Home Page : %s",
+				    szRealAddr,
+				    (pszRealName != NULL) ? pszRealName : "??",
+				    (pszHomePage != NULL) ? pszHomePage : "??");
 
 			BSckSendString(hBSock, szRespBuffer, pFINGCfg->iTimeout);
 
-			if (pszRealName != NULL)
-				SysFree(pszRealName);
-
-			if (pszHomePage != NULL)
-				SysFree(pszHomePage);
+			SysFree(pszRealName);
+			SysFree(pszHomePage);
 		} else {
-///////////////////////////////////////////////////////////////////////////////
-//  Local mailing list case
-///////////////////////////////////////////////////////////////////////////////
+			/* Local mailing list case */
 
 			FINGDumpMailingList(pUI, hBSock, pFINGCfg);
 		}
-
 		UsrFreeUserInfo(pUI);
 	} else {
 		ErrSetErrorCode(ERR_USER_NOT_FOUND);
-		return (ERR_USER_NOT_FOUND);
+		return ERR_USER_NOT_FOUND;
 	}
 
-	return (0);
-
+	return 0;
 }
 
 static int FINGDumpMailingList(UserInfo * pUI, BSOCK_HANDLE hBSock, FINGConfig * pFINGCfg)
 {
-
 	USRML_HANDLE hUsersDB = UsrMLOpenDB(pUI);
 
 	if (hUsersDB == INVALID_USRML_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
-///////////////////////////////////////////////////////////////////////////////
-//  Mailing list scan
-///////////////////////////////////////////////////////////////////////////////
+	/* Mailing list scan */
 	MLUserInfo *pMLUI = UsrMLGetFirstUser(hUsersDB);
 
 	for (; pMLUI != NULL; pMLUI = UsrMLGetNextUser(hUsersDB)) {
@@ -548,18 +431,15 @@ static int FINGDumpMailingList(UserInfo * pUI, BSOCK_HANDLE hBSock, FINGConfig *
 			ErrorPush();
 			UsrMLFreeUser(pMLUI);
 			UsrMLCloseDB(hUsersDB);
-			return (ErrorPop());
+			return ErrorPop();
 		}
-///////////////////////////////////////////////////////////////////////////////
-//  Dump user
-///////////////////////////////////////////////////////////////////////////////
+		/* Dump user */
 		FINGDumpUser(szUser, szDomain, hBSock, pFINGCfg);
 
 		UsrMLFreeUser(pMLUI);
 	}
-
 	UsrMLCloseDB(hUsersDB);
 
-	return (0);
-
+	return 0;
 }
+
