@@ -39,17 +39,18 @@
 #define SVR_LINKS_FILE              "pop3links.tab"
 #define SVR_LINKS_ENABLE_DIR        "pop3links"
 #define SVR_POP3LOCKS_DIR           "pop3linklocks"
+#define SVR_MSGSYNCDB_DIR           "msgsync"
 #define LINKS_TABLE_LINE_MAX        2048
 
 enum LinksFileds {
 	lnkDomain = 0,
-	lnkName,
-	lnkRmtDomain,
-	lnkRmtName,
-	lnkRmtPassword,
-	lnkAuthType,
+		lnkName,
+		lnkRmtDomain,
+		lnkRmtName,
+		lnkRmtPassword,
+		lnkAuthType,
 
-	lnkMax
+		lnkMax
 };
 
 struct GwLkDBScanData {
@@ -60,62 +61,65 @@ struct GwLkDBScanData {
 static char *GwLkGetTableFilePath(char *pszLnkFilePath, int iMaxPath);
 static char *GwLkEnableDir(char *pszEnableDir, int iMaxPath);
 static char *GwLkGetLocksDir(char *pszLocksDir, int iMaxPath);
+static char *GwLkGetMsgSyncDbDir(char *pszMsgSyncDir, int iMaxPath);
 static POP3Link *GwLkGetLinkFromStrings(char **ppszStrings);
-static int GwLkWriteLink(FILE * pLnkFile, POP3Link * pPopLnk);
+static int GwLkWriteLink(FILE *pLnkFile, POP3Link *pPopLnk);
 static char *GwLkSanitizeFileName(char const *pszInName, char *pszOutName, int iOutSize);
 static char *GwLkGetLockFileName(POP3Link const *pPopLnk, char *pszLockFile);
 static int GwLkGetDisableFilePath(POP3Link const *pPopLnk, char *pszEnableFile);
 
 static char *GwLkGetTableFilePath(char *pszLnkFilePath, int iMaxPath)
 {
-
 	CfgGetRootPath(pszLnkFilePath, iMaxPath);
 
 	StrNCat(pszLnkFilePath, SVR_LINKS_FILE, iMaxPath);
 
-	return (pszLnkFilePath);
-
+	return pszLnkFilePath;
 }
 
 static char *GwLkEnableDir(char *pszEnableDir, int iMaxPath)
 {
-
 	CfgGetRootPath(pszEnableDir, iMaxPath);
 
 	StrNCat(pszEnableDir, SVR_LINKS_ENABLE_DIR, iMaxPath);
 
-	return (pszEnableDir);
-
+	return pszEnableDir;
 }
 
 static char *GwLkGetLocksDir(char *pszLocksDir, int iMaxPath)
 {
-
 	CfgGetRootPath(pszLocksDir, iMaxPath);
 
 	StrNCat(pszLocksDir, SVR_POP3LOCKS_DIR, iMaxPath);
 
-	return (pszLocksDir);
+	return pszLocksDir;
+}
 
+static char *GwLkGetMsgSyncDbDir(char *pszMsgSyncDir, int iMaxPath)
+{
+	CfgGetRootPath(pszMsgSyncDir, iMaxPath);
+
+	StrNCat(pszMsgSyncDir, SVR_MSGSYNCDB_DIR, iMaxPath);
+
+	return pszMsgSyncDir;
 }
 
 static POP3Link *GwLkGetLinkFromStrings(char **ppszStrings)
 {
-
 	int iFieldsCount = StrStringsCount(ppszStrings);
 
 	if (iFieldsCount < lnkMax)
-		return (NULL);
+		return NULL;
 
 	char szPassword[512] = "";
 
 	if (StrDeCrypt(ppszStrings[lnkRmtPassword], szPassword) == NULL)
-		return (NULL);
+		return NULL;
 
 	POP3Link *pPopLnk = (POP3Link *) SysAlloc(sizeof(POP3Link));
 
 	if (pPopLnk == NULL)
-		return (NULL);
+		return NULL;
 
 	pPopLnk->pszDomain = SysStrDup(ppszStrings[lnkDomain]);
 	pPopLnk->pszName = SysStrDup(ppszStrings[lnkName]);
@@ -124,19 +128,17 @@ static POP3Link *GwLkGetLinkFromStrings(char **ppszStrings)
 	pPopLnk->pszRmtPassword = SysStrDup(szPassword);
 	pPopLnk->pszAuthType = SysStrDup(ppszStrings[lnkAuthType]);
 
-	return (pPopLnk);
-
+	return pPopLnk;
 }
 
 POP3Link *GwLkAllocLink(char const *pszDomain, char const *pszName,
 			char const *pszRmtDomain, char const *pszRmtName,
 			char const *pszRmtPassword, char const *pszAuthType)
 {
-
 	POP3Link *pPopLnk = (POP3Link *) SysAlloc(sizeof(POP3Link));
 
 	if (pPopLnk == NULL)
-		return (NULL);
+		return NULL;
 
 	pPopLnk->pszDomain = (pszDomain != NULL) ? SysStrDup(pszDomain) : NULL;
 	pPopLnk->pszName = (pszName != NULL) ? SysStrDup(pszName) : NULL;
@@ -145,89 +147,63 @@ POP3Link *GwLkAllocLink(char const *pszDomain, char const *pszName,
 	pPopLnk->pszRmtPassword = (pszRmtPassword != NULL) ? SysStrDup(pszRmtPassword) : NULL;
 	pPopLnk->pszAuthType = (pszAuthType != NULL) ? SysStrDup(pszAuthType) : NULL;
 
-	return (pPopLnk);
-
+	return pPopLnk;
 }
 
-void GwLkFreePOP3Link(POP3Link * pPopLnk)
+void GwLkFreePOP3Link(POP3Link *pPopLnk)
 {
-
-	if (pPopLnk->pszDomain != NULL)
-		SysFree(pPopLnk->pszDomain);
-
-	if (pPopLnk->pszName != NULL)
-		SysFree(pPopLnk->pszName);
-
-	if (pPopLnk->pszRmtDomain != NULL)
-		SysFree(pPopLnk->pszRmtDomain);
-
-	if (pPopLnk->pszRmtName != NULL)
-		SysFree(pPopLnk->pszRmtName);
-
-	if (pPopLnk->pszRmtPassword != NULL)
-		SysFree(pPopLnk->pszRmtPassword);
-
-	if (pPopLnk->pszAuthType != NULL)
-		SysFree(pPopLnk->pszAuthType);
-
+	SysFree(pPopLnk->pszDomain);
+	SysFree(pPopLnk->pszName);
+	SysFree(pPopLnk->pszRmtDomain);
+	SysFree(pPopLnk->pszRmtName);
+	SysFree(pPopLnk->pszRmtPassword);
+	SysFree(pPopLnk->pszAuthType);
 	SysFree(pPopLnk);
-
 }
 
-static int GwLkWriteLink(FILE * pLnkFile, POP3Link * pPopLnk)
+static int GwLkWriteLink(FILE *pLnkFile, POP3Link *pPopLnk)
 {
-
-///////////////////////////////////////////////////////////////////////////////
-//  Domain
-///////////////////////////////////////////////////////////////////////////////
+	/* Domain */
 	char *pszQuoted = StrQuote(pPopLnk->pszDomain, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pLnkFile, "%s\t", pszQuoted);
 
 	SysFree(pszQuoted);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Local user
-///////////////////////////////////////////////////////////////////////////////
+	/* Local user */
 	pszQuoted = StrQuote(pPopLnk->pszName, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pLnkFile, "%s\t", pszQuoted);
 
 	SysFree(pszQuoted);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Remote domain
-///////////////////////////////////////////////////////////////////////////////
+	/* Remote domain */
 	pszQuoted = StrQuote(pPopLnk->pszRmtDomain, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pLnkFile, "%s\t", pszQuoted);
 
 	SysFree(pszQuoted);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Remote user
-///////////////////////////////////////////////////////////////////////////////
+	/* Remote user */
 	pszQuoted = StrQuote(pPopLnk->pszRmtName, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pLnkFile, "%s\t", pszQuoted);
 
 	SysFree(pszQuoted);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Remote password
-///////////////////////////////////////////////////////////////////////////////
+	/* Remote password */
 	char szPassword[512] = "";
 
 	StrCrypt(pPopLnk->pszRmtPassword, szPassword);
@@ -235,31 +211,27 @@ static int GwLkWriteLink(FILE * pLnkFile, POP3Link * pPopLnk)
 	pszQuoted = StrQuote(szPassword, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pLnkFile, "%s\t", pszQuoted);
 
 	SysFree(pszQuoted);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Authentication type
-///////////////////////////////////////////////////////////////////////////////
+	/* Authentication type */
 	pszQuoted = StrQuote(pPopLnk->pszAuthType, '"');
 
 	if (pszQuoted == NULL)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	fprintf(pLnkFile, "%s\n", pszQuoted);
 
 	SysFree(pszQuoted);
 
-	return (0);
-
+	return 0;
 }
 
-int GwLkAddLink(POP3Link * pPopLnk)
+int GwLkAddLink(POP3Link *pPopLnk)
 {
-
 	char szLnkFilePath[SYS_MAX_PATH] = "";
 
 	GwLkGetTableFilePath(szLnkFilePath, sizeof(szLnkFilePath));
@@ -269,7 +241,7 @@ int GwLkAddLink(POP3Link * pPopLnk)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	FILE *pLnkFile = fopen(szLnkFilePath, "r+t");
 
@@ -277,7 +249,7 @@ int GwLkAddLink(POP3Link * pPopLnk)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_LINKS_FILE_NOT_FOUND);
-		return (ERR_LINKS_FILE_NOT_FOUND);
+		return ERR_LINKS_FILE_NOT_FOUND;
 	}
 
 	char szLnkLine[LINKS_TABLE_LINE_MAX] = "";
@@ -290,43 +262,38 @@ int GwLkAddLink(POP3Link * pPopLnk)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= lnkMax) &&
-		    (stricmp(pPopLnk->pszDomain, ppszStrings[lnkDomain]) == 0) &&
-		    (stricmp(pPopLnk->pszName, ppszStrings[lnkName]) == 0) &&
-		    (stricmp(pPopLnk->pszRmtDomain, ppszStrings[lnkRmtDomain]) == 0) &&
-		    (stricmp(pPopLnk->pszRmtName, ppszStrings[lnkRmtName]) == 0)) {
+		if (iFieldsCount >= lnkMax &&
+		    stricmp(pPopLnk->pszDomain, ppszStrings[lnkDomain]) == 0 &&
+		    stricmp(pPopLnk->pszName, ppszStrings[lnkName]) == 0 &&
+		    stricmp(pPopLnk->pszRmtDomain, ppszStrings[lnkRmtDomain]) == 0 &&
+		    stricmp(pPopLnk->pszRmtName, ppszStrings[lnkRmtName]) == 0) {
 			StrFreeStrings(ppszStrings);
 			fclose(pLnkFile);
 			RLckUnlockEX(hResLock);
 
 			ErrSetErrorCode(ERR_LINK_EXIST);
-			return (ERR_LINK_EXIST);
+			return ERR_LINK_EXIST;
 		}
-
 		StrFreeStrings(ppszStrings);
 	}
 
 	fseek(pLnkFile, 0, SEEK_END);
-
 	if (GwLkWriteLink(pLnkFile, pPopLnk) < 0) {
 		fclose(pLnkFile);
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_WRITE_LINKS_FILE);
-		return (ERR_WRITE_LINKS_FILE);
+		return ERR_WRITE_LINKS_FILE;
 	}
-
 	fclose(pLnkFile);
 
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
-int GwLkRemoveLink(POP3Link * pPopLnk)
+int GwLkRemoveLink(POP3Link *pPopLnk)
 {
-
 	char szLnkFilePath[SYS_MAX_PATH] = "";
 
 	GwLkGetTableFilePath(szLnkFilePath, sizeof(szLnkFilePath));
@@ -340,7 +307,7 @@ int GwLkRemoveLink(POP3Link * pPopLnk)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	FILE *pLnkFile = fopen(szLnkFilePath, "rt");
 
@@ -348,7 +315,7 @@ int GwLkRemoveLink(POP3Link * pPopLnk)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_LINKS_FILE_NOT_FOUND);
-		return (ERR_LINKS_FILE_NOT_FOUND);
+		return ERR_LINKS_FILE_NOT_FOUND;
 	}
 
 	FILE *pTmpFile = fopen(szTmpFile, "wt");
@@ -358,7 +325,7 @@ int GwLkRemoveLink(POP3Link * pPopLnk)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_FILE_CREATE);
-		return (ERR_FILE_CREATE);
+		return ERR_FILE_CREATE;
 	}
 
 	int iLinksFound = 0;
@@ -377,20 +344,16 @@ int GwLkRemoveLink(POP3Link * pPopLnk)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= lnkMax) &&
-		    (stricmp(pPopLnk->pszDomain, ppszStrings[lnkDomain]) == 0) &&
-		    (stricmp(pPopLnk->pszName, ppszStrings[lnkName]) == 0) &&
-		    (stricmp(pPopLnk->pszRmtDomain, ppszStrings[lnkRmtDomain]) == 0) &&
-		    (stricmp(pPopLnk->pszRmtName, ppszStrings[lnkRmtName]) == 0)) {
-
+		if (iFieldsCount >= lnkMax &&
+		    stricmp(pPopLnk->pszDomain, ppszStrings[lnkDomain]) == 0 &&
+		    stricmp(pPopLnk->pszName, ppszStrings[lnkName]) == 0 &&
+		    stricmp(pPopLnk->pszRmtDomain, ppszStrings[lnkRmtDomain]) == 0 &&
+		    stricmp(pPopLnk->pszRmtName, ppszStrings[lnkRmtName]) == 0) {
 			++iLinksFound;
-
 		} else
 			fprintf(pTmpFile, "%s\n", szLnkLine);
-
 		StrFreeStrings(ppszStrings);
 	}
-
 	fclose(pLnkFile);
 	fclose(pTmpFile);
 
@@ -399,50 +362,36 @@ int GwLkRemoveLink(POP3Link * pPopLnk)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_LINK_NOT_FOUND);
-		return (ERR_LINK_NOT_FOUND);
+		return ERR_LINK_NOT_FOUND;
 	}
-
-	char szTmpLnkFilePath[SYS_MAX_PATH] = "";
-
-	sprintf(szTmpLnkFilePath, "%s.tmp", szLnkFilePath);
-
-	if (MscMoveFile(szLnkFilePath, szTmpLnkFilePath) < 0) {
-		ErrorPush();
-		RLckUnlockEX(hResLock);
-		return (ErrorPop());
-	}
-
 	if (MscMoveFile(szTmpFile, szLnkFilePath) < 0) {
 		ErrorPush();
-		MscMoveFile(szTmpLnkFilePath, szLnkFilePath);
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
-	SysRemove(szTmpLnkFilePath);
+	/* Remove the disable file if exist */
+	char szRmFilePath[SYS_MAX_PATH] = "";
 
-///////////////////////////////////////////////////////////////////////////////
-//  Remove the disable file if exist
-///////////////////////////////////////////////////////////////////////////////
-	char szEnableFile[SYS_MAX_PATH] = "";
-
-	if (GwLkGetDisableFilePath(pPopLnk, szEnableFile) < 0) {
+	if (GwLkGetDisableFilePath(pPopLnk, szRmFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
+	CheckRemoveFile(szRmFilePath);
 
-	CheckRemoveFile(szEnableFile);
+	/* Remove the UIDL DB file for the account */
+	if (GwLkGetMsgSyncDbFile(pPopLnk->pszRmtDomain, pPopLnk->pszRmtName,
+				 szRmFilePath, sizeof(szRmFilePath) - 1) == 0)
+		CheckRemoveFile(szRmFilePath);
 
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 int GwLkRemoveUserLinks(const char *pszDomain, const char *pszName)
 {
-
 	char szLnkFilePath[SYS_MAX_PATH] = "";
 
 	GwLkGetTableFilePath(szLnkFilePath, sizeof(szLnkFilePath));
@@ -458,7 +407,7 @@ int GwLkRemoveUserLinks(const char *pszDomain, const char *pszName)
 	if (hResLock == INVALID_RLCK_HANDLE) {
 		ErrorPush();
 		CheckRemoveFile(szTmpFile);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
 	FILE *pLnkFile = fopen(szLnkFilePath, "rt");
@@ -467,7 +416,7 @@ int GwLkRemoveUserLinks(const char *pszDomain, const char *pszName)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_LINKS_FILE_NOT_FOUND);
-		return (ERR_LINKS_FILE_NOT_FOUND);
+		return ERR_LINKS_FILE_NOT_FOUND;
 	}
 
 	FILE *pTmpFile = fopen(szTmpFile, "wt");
@@ -477,7 +426,7 @@ int GwLkRemoveUserLinks(const char *pszDomain, const char *pszName)
 		RLckUnlockEX(hResLock);
 
 		ErrSetErrorCode(ERR_FILE_CREATE);
-		return (ERR_FILE_CREATE);
+		return ERR_FILE_CREATE;
 	}
 
 	int iLinksFound = 0;
@@ -496,54 +445,33 @@ int GwLkRemoveUserLinks(const char *pszDomain, const char *pszName)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= lnkMax) && (stricmp(pszDomain, ppszStrings[lnkDomain]) == 0)
-		    && (stricmp(pszName, ppszStrings[lnkName]) == 0)) {
-
+		if (iFieldsCount >= lnkMax && stricmp(pszDomain, ppszStrings[lnkDomain]) == 0 &&
+		    stricmp(pszName, ppszStrings[lnkName]) == 0) {
 			++iLinksFound;
-
 		} else
 			fprintf(pTmpFile, "%s\n", szLnkLine);
-
 		StrFreeStrings(ppszStrings);
 	}
-
 	fclose(pLnkFile);
 	fclose(pTmpFile);
 
 	if (iLinksFound == 0) {
 		SysRemove(szTmpFile);
 		RLckUnlockEX(hResLock);
-		return (0);
+		return 0;
 	}
-
-	char szTmpLnkFilePath[SYS_MAX_PATH] = "";
-
-	sprintf(szTmpLnkFilePath, "%s.tmp", szLnkFilePath);
-
-	if (MscMoveFile(szLnkFilePath, szTmpLnkFilePath) < 0) {
-		ErrorPush();
-		RLckUnlockEX(hResLock);
-		return (ErrorPop());
-	}
-
 	if (MscMoveFile(szTmpFile, szLnkFilePath) < 0) {
 		ErrorPush();
-		MscMoveFile(szTmpLnkFilePath, szLnkFilePath);
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
-
-	SysRemove(szTmpLnkFilePath);
-
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 int GwLkRemoveDomainLinks(const char *pszDomain)
 {
-
 	char szLnkFilePath[SYS_MAX_PATH] = "";
 
 	GwLkGetTableFilePath(szLnkFilePath, sizeof(szLnkFilePath));
@@ -559,7 +487,7 @@ int GwLkRemoveDomainLinks(const char *pszDomain)
 	if (hResLock == INVALID_RLCK_HANDLE) {
 		ErrorPush();
 		CheckRemoveFile(szTmpFile);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
 	FILE *pLnkFile = fopen(szLnkFilePath, "rt");
@@ -569,7 +497,7 @@ int GwLkRemoveDomainLinks(const char *pszDomain)
 		CheckRemoveFile(szTmpFile);
 
 		ErrSetErrorCode(ERR_LINKS_FILE_NOT_FOUND);
-		return (ERR_LINKS_FILE_NOT_FOUND);
+		return ERR_LINKS_FILE_NOT_FOUND;
 	}
 
 	FILE *pTmpFile = fopen(szTmpFile, "wt");
@@ -580,7 +508,7 @@ int GwLkRemoveDomainLinks(const char *pszDomain)
 		CheckRemoveFile(szTmpFile);
 
 		ErrSetErrorCode(ERR_FILE_CREATE);
-		return (ERR_FILE_CREATE);
+		return ERR_FILE_CREATE;
 	}
 
 	int iLinksFound = 0;
@@ -599,55 +527,33 @@ int GwLkRemoveDomainLinks(const char *pszDomain)
 
 		int iFieldsCount = StrStringsCount(ppszStrings);
 
-		if ((iFieldsCount >= lnkMax) && (stricmp(pszDomain, ppszStrings[lnkDomain]) == 0)) {
+		if (iFieldsCount >= lnkMax && stricmp(pszDomain, ppszStrings[lnkDomain]) == 0) {
 
 			++iLinksFound;
-
 		} else
 			fprintf(pTmpFile, "%s\n", szLnkLine);
-
 		StrFreeStrings(ppszStrings);
 	}
-
 	fclose(pLnkFile);
 	fclose(pTmpFile);
 
 	if (iLinksFound == 0) {
 		SysRemove(szTmpFile);
 		RLckUnlockEX(hResLock);
-		return (0);
+		return 0;
 	}
-
-	char szTmpLnkFilePath[SYS_MAX_PATH] = "";
-
-	sprintf(szTmpLnkFilePath, "%s.tmp", szLnkFilePath);
-
-	if (MscMoveFile(szLnkFilePath, szTmpLnkFilePath) < 0) {
-		ErrorPush();
-		SysRemove(szTmpFile);
-		RLckUnlockEX(hResLock);
-		return (ErrorPop());
-	}
-
 	if (MscMoveFile(szTmpFile, szLnkFilePath) < 0) {
 		ErrorPush();
-		MscMoveFile(szTmpLnkFilePath, szLnkFilePath);
-		SysRemove(szTmpFile);
 		RLckUnlockEX(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
-
-	SysRemove(szTmpLnkFilePath);
-
 	RLckUnlockEX(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 int GwLkGetDBFileSnapShot(const char *pszFileName)
 {
-
 	char szGwLkFilePath[SYS_MAX_PATH] = "";
 
 	GwLkGetTableFilePath(szGwLkFilePath, sizeof(szGwLkFilePath));
@@ -657,63 +563,53 @@ int GwLkGetDBFileSnapShot(const char *pszFileName)
 							  sizeof(szResLock)));
 
 	if (hResLock == INVALID_RLCK_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	if (MscCopyFile(pszFileName, szGwLkFilePath) < 0) {
 		ErrorPush();
 		RLckUnlockSH(hResLock);
-		return (ErrorPop());
+		return ErrorPop();
 	}
 
 	RLckUnlockSH(hResLock);
 
-	return (0);
-
+	return 0;
 }
 
 GWLKF_HANDLE GwLkOpenDB(void)
 {
-
 	GwLkDBScanData *pGLSD = (GwLkDBScanData *) SysAlloc(sizeof(GwLkDBScanData));
 
 	if (pGLSD == NULL)
-		return (INVALID_GWLKF_HANDLE);
+		return INVALID_GWLKF_HANDLE;
 
 	SysGetTmpFile(pGLSD->szTmpDBFile);
-
 	if (GwLkGetDBFileSnapShot(pGLSD->szTmpDBFile) < 0) {
 		SysFree(pGLSD);
-		return (INVALID_GWLKF_HANDLE);
+		return INVALID_GWLKF_HANDLE;
 	}
-
 	if ((pGLSD->pDBFile = fopen(pGLSD->szTmpDBFile, "rt")) == NULL) {
 		SysRemove(pGLSD->szTmpDBFile);
 		SysFree(pGLSD);
 
 		ErrSetErrorCode(ERR_FILE_OPEN);
-		return (INVALID_GWLKF_HANDLE);
+		return INVALID_GWLKF_HANDLE;
 	}
 
-	return ((GWLKF_HANDLE) pGLSD);
-
+	return (GWLKF_HANDLE) pGLSD;
 }
 
 void GwLkCloseDB(GWLKF_HANDLE hLinksDB)
 {
-
 	GwLkDBScanData *pGLSD = (GwLkDBScanData *) hLinksDB;
 
 	fclose(pGLSD->pDBFile);
-
 	SysRemove(pGLSD->szTmpDBFile);
-
 	SysFree(pGLSD);
-
 }
 
 POP3Link *GwLkGetFirstUser(GWLKF_HANDLE hLinksDB)
 {
-
 	GwLkDBScanData *pGLSD = (GwLkDBScanData *) hLinksDB;
 
 	rewind(pGLSD->pDBFile);
@@ -736,20 +632,18 @@ POP3Link *GwLkGetFirstUser(GWLKF_HANDLE hLinksDB)
 		StrFreeStrings(ppszStrings);
 	}
 
-	return (pPopLnk);
-
+	return pPopLnk;
 }
 
 POP3Link *GwLkGetNextUser(GWLKF_HANDLE hLinksDB)
 {
-
 	GwLkDBScanData *pGLSD = (GwLkDBScanData *) hLinksDB;
 
 	POP3Link *pPopLnk = NULL;
 	char szLnkLine[LINKS_TABLE_LINE_MAX] = "";
 
-	while ((pPopLnk == NULL) &&
-	       (MscGetConfigLine(szLnkLine, sizeof(szLnkLine) - 1, pGLSD->pDBFile) != NULL)) {
+	while (pPopLnk == NULL &&
+	       MscGetConfigLine(szLnkLine, sizeof(szLnkLine) - 1, pGLSD->pDBFile) != NULL) {
 		char **ppszStrings = StrGetTabLineStrings(szLnkLine);
 
 		if (ppszStrings == NULL)
@@ -763,13 +657,11 @@ POP3Link *GwLkGetNextUser(GWLKF_HANDLE hLinksDB)
 		StrFreeStrings(ppszStrings);
 	}
 
-	return (pPopLnk);
-
+	return pPopLnk;
 }
 
 static char *GwLkSanitizeFileName(char const *pszInName, char *pszOutName, int iOutSize)
 {
-
 	int i;
 
 	for (i = 0, iOutSize--; i < iOutSize && *pszInName != '\0'; i++, pszInName++) {
@@ -785,12 +677,11 @@ static char *GwLkSanitizeFileName(char const *pszInName, char *pszOutName, int i
 	}
 	pszOutName[i] = '\0';
 
-	return (pszOutName);
+	return pszOutName;
 }
 
 static char *GwLkGetLockFileName(POP3Link const *pPopLnk, char *pszLockFile)
 {
-
 	char szLocksDir[SYS_MAX_PATH] = "";
 	char szRmtDomain[MAX_HOST_NAME] = "";
 	char szRmtName[MAX_HOST_NAME] = "";
@@ -800,120 +691,125 @@ static char *GwLkGetLockFileName(POP3Link const *pPopLnk, char *pszLockFile)
 	GwLkSanitizeFileName(pPopLnk->pszRmtDomain, szRmtDomain, sizeof(szRmtDomain) - 1);
 	GwLkSanitizeFileName(pPopLnk->pszRmtName, szRmtName, sizeof(szRmtName) - 1);
 
-	sprintf(pszLockFile, "%s%s%s@%s", szLocksDir, SYS_SLASH_STR, szRmtName,
-		szRmtDomain);
+	SysSNPrintf(pszLockFile, SYS_MAX_PATH - 1, "%s%s%s@%s", szLocksDir, SYS_SLASH_STR, szRmtName,
+		    szRmtDomain);
 
-	return (pszLockFile);
+	return pszLockFile;
+}
 
+int GwLkGetMsgSyncDbFile(char const *pszRmtDomain, char const *pszRmtName,
+			 char *pszMsgSyncFile, int iMaxPath)
+{
+	char szMsgSyncDir[SYS_MAX_PATH] = "";
+	char szRmtDomain[MAX_HOST_NAME] = "";
+	char szRmtName[MAX_HOST_NAME] = "";
+
+	GwLkGetMsgSyncDbDir(szMsgSyncDir, sizeof(szMsgSyncDir));
+	GwLkSanitizeFileName(pszRmtDomain, szRmtDomain, sizeof(szRmtDomain) - 1);
+	GwLkSanitizeFileName(pszRmtName, szRmtName, sizeof(szRmtName) - 1);
+
+	SysSNPrintf(pszMsgSyncFile, iMaxPath, "%s%s%s", szMsgSyncDir, SYS_SLASH_STR,
+		    szRmtDomain);
+	if (!SysExistDir(pszMsgSyncFile) && SysMakeDir(pszMsgSyncFile) < 0)
+		return ErrGetErrorCode();
+
+	int iLength = strlen(pszMsgSyncFile);
+
+	SysSNPrintf(pszMsgSyncFile + iLength, iMaxPath - iLength, SYS_SLASH_STR "%s.uidb",
+		    szRmtName);
+
+	return 0;
 }
 
 int GwLkLinkLock(POP3Link const *pPopLnk)
 {
-
 	char szLockFile[SYS_MAX_PATH] = "";
 
 	GwLkGetLockFileName(pPopLnk, szLockFile);
 
-	return (SysLockFile(szLockFile));
-
+	return SysLockFile(szLockFile);
 }
 
 void GwLkLinkUnlock(POP3Link const *pPopLnk)
 {
-
 	char szLockFile[SYS_MAX_PATH] = "";
 
 	GwLkGetLockFileName(pPopLnk, szLockFile);
 
 	SysUnlockFile(szLockFile);
-
 }
 
 int GwLkClearLinkLocksDir(void)
 {
-
 	char szLocksDir[SYS_MAX_PATH] = "";
 
 	GwLkGetLocksDir(szLocksDir, sizeof(szLocksDir));
 
-	return (MscClearDirectory(szLocksDir));
-
+	return MscClearDirectory(szLocksDir);
 }
 
 int GwLkLocalDomain(POP3Link const *pPopLnk)
 {
-
-	return (((pPopLnk != NULL) && (pPopLnk->pszDomain[0] != '@') &&
-		 (pPopLnk->pszDomain[0] != '?') && (pPopLnk->pszDomain[0] != '&')) ? 1 : 0);
-
+	return ((pPopLnk != NULL && pPopLnk->pszDomain[0] != '@' &&
+		 pPopLnk->pszDomain[0] != '?' && pPopLnk->pszDomain[0] != '&') ? 1: 0);
 }
 
 int GwLkMasqueradeDomain(POP3Link const *pPopLnk)
 {
-
-	return (((pPopLnk != NULL) &&
-		 ((pPopLnk->pszDomain[0] == '?') || (pPopLnk->pszDomain[0] == '&'))) ? 1 : 0);
-
+	return ((pPopLnk != NULL &&
+		 (pPopLnk->pszDomain[0] == '?' || pPopLnk->pszDomain[0] == '&')) ? 1: 0);
 }
 
 static int GwLkGetDisableFilePath(POP3Link const *pPopLnk, char *pszEnableFile)
 {
-
 	if (GwLkLocalDomain(pPopLnk)) {
 		UserInfo *pUI = UsrGetUserByName(pPopLnk->pszDomain, pPopLnk->pszName);
 
 		if (pUI == NULL)
-			return (ErrGetErrorCode());
+			return ErrGetErrorCode();
 
 		char szUserPath[SYS_MAX_PATH] = "";
 
 		if (UsrGetUserPath(pUI, szUserPath, sizeof(szUserPath), 1) == NULL) {
 			ErrorPush();
 			UsrFreeUserInfo(pUI);
-			return (ErrorPop());
+			return ErrorPop();
 		}
-
 		UsrFreeUserInfo(pUI);
-
-		sprintf(pszEnableFile, "%s%s@%s.disabled", szUserPath, pPopLnk->pszRmtName,
-			pPopLnk->pszRmtDomain);
+		SysSNPrintf(pszEnableFile, SYS_MAX_PATH - 1, "%s%s@%s.disabled", szUserPath,
+			    pPopLnk->pszRmtName, pPopLnk->pszRmtDomain);
 	} else {
 		char szEnableDir[SYS_MAX_PATH] = "";
 
 		GwLkEnableDir(szEnableDir, sizeof(szEnableDir));
 
-		sprintf(pszEnableFile, "%s%s%s@%s.disabled", szEnableDir, SYS_SLASH_STR,
-			pPopLnk->pszRmtName, pPopLnk->pszRmtDomain);
+		SysSNPrintf(pszEnableFile, SYS_MAX_PATH - 1, "%s%s%s@%s.disabled", szEnableDir,
+			    SYS_SLASH_STR, pPopLnk->pszRmtName, pPopLnk->pszRmtDomain);
 	}
 
-	return (0);
-
+	return 0;
 }
 
 int GwLkCheckEnabled(POP3Link const *pPopLnk)
 {
-
 	char szEnableFile[SYS_MAX_PATH] = "";
 
 	if (GwLkGetDisableFilePath(pPopLnk, szEnableFile) < 0)
-		return (ErrGetErrorCode());
-
+		return ErrGetErrorCode();
 	if (SysExistFile(szEnableFile)) {
 		ErrSetErrorCode(ERR_POP3_EXTERNAL_LINK_DISABLED);
-		return (ERR_POP3_EXTERNAL_LINK_DISABLED);
+		return ERR_POP3_EXTERNAL_LINK_DISABLED;
 	}
 
-	return (0);
-
+	return 0;
 }
 
 int GwLkEnable(POP3Link const *pPopLnk, bool bEnable)
 {
-
 	char szEnableFile[SYS_MAX_PATH] = "";
 
 	if (GwLkGetDisableFilePath(pPopLnk, szEnableFile) < 0)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	if (bEnable)
 		CheckRemoveFile(szEnableFile);
@@ -922,7 +818,7 @@ int GwLkEnable(POP3Link const *pPopLnk, bool bEnable)
 
 		if (pFile == NULL) {
 			ErrSetErrorCode(ERR_FILE_CREATE);
-			return (ERR_FILE_CREATE);
+			return ERR_FILE_CREATE;
 		}
 
 		time_t tCurr;
@@ -935,54 +831,43 @@ int GwLkEnable(POP3Link const *pPopLnk, bool bEnable)
 		SysLocalTime(&tCurr, &tmTime);
 
 		strftime(szTime, sizeof(szTime), "%d %b %Y %H:%M:%S %Z", &tmTime);
-
 		fprintf(pFile, "%s\n", szTime);
-
 		fclose(pFile);
 	}
 
-	return (0);
-
+	return 0;
 }
 
 int GwLkEnable(char const *pszDomain, char const *pszName,
 	       char const *pszRmtDomain, char const *pszRmtName, bool bEnable)
 {
-
 	GWLKF_HANDLE hLinksDB = GwLkOpenDB();
 
 	if (hLinksDB == INVALID_GWLKF_HANDLE)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	int iMatchingUsers = 0;
 	POP3Link *pPopLnk = GwLkGetFirstUser(hLinksDB);
 
 	for (; pPopLnk != NULL; pPopLnk = GwLkGetNextUser(hLinksDB)) {
-		if ((stricmp(pPopLnk->pszDomain, pszDomain) == 0) &&
-		    (stricmp(pPopLnk->pszName, pszName) == 0) &&
-		    ((pszRmtDomain == NULL) ||
-		     (stricmp(pPopLnk->pszRmtDomain, pszRmtDomain) == 0)) && ((pszRmtName == NULL)
-									      ||
-									      (stricmp
-									       (pPopLnk->
-										pszRmtName,
-										pszRmtName) ==
-									       0))) {
+		if (stricmp(pPopLnk->pszDomain, pszDomain) == 0 &&
+		    stricmp(pPopLnk->pszName, pszName) == 0 &&
+		    (pszRmtDomain == NULL ||
+		     stricmp(pPopLnk->pszRmtDomain, pszRmtDomain) == 0) &&
+		    (pszRmtName == NULL ||
+		     stricmp(pPopLnk->pszRmtName, pszRmtName) == 0)) {
 			GwLkEnable(pPopLnk, bEnable);
-
 			++iMatchingUsers;
 		}
-
 		GwLkFreePOP3Link(pPopLnk);
 	}
-
 	GwLkCloseDB(hLinksDB);
 
 	if (iMatchingUsers == 0) {
 		ErrSetErrorCode(ERR_LINK_NOT_FOUND);
-		return (ERR_LINK_NOT_FOUND);
+		return ERR_LINK_NOT_FOUND;
 	}
 
-	return (0);
-
+	return 0;
 }
+
