@@ -54,8 +54,8 @@ struct LocalMailProcConfig {
 
 typedef void *TAG_POSITION;
 
-int USmlLoadSpoolFileHeader(char const *pszSpoolFile, SpoolFileHeader & SFH);
-void USmlCleanupSpoolFileHeader(SpoolFileHeader & SFH);
+int USmlLoadSpoolFileHeader(char const *pszSpoolFile, SpoolFileHeader &SFH);
+void USmlCleanupSpoolFileHeader(SpoolFileHeader &SFH);
 char *USmlAddrConcat(char const *const *ppszStrings);
 char *USmlBuildSendMailFrom(char const *const *ppszFrom, char const *const *ppszRcpt);
 char *USmlBuildSendRcptTo(char const *const *ppszFrom, char const *const *ppszRcpt);
@@ -74,22 +74,23 @@ char const *USmlSendMailFrom(SPLF_HANDLE hFSpool);
 char const *const *USmlGetRcptTo(SPLF_HANDLE hFSpool);
 char const *USmlRcptTo(SPLF_HANDLE hFSpool);
 char const *USmlSendRcptTo(SPLF_HANDLE hFSpool);
+SYS_OFF_T USmlMessageSize(SPLF_HANDLE hFSpool);
 int USmlSyncChanges(SPLF_HANDLE hFSpool);
-int USmlGetMsgFileSection(SPLF_HANDLE hFSpool, FileSection & FS);
-int USmlWriteMailFile(SPLF_HANDLE hFSpool, FILE * pMsgFile);
-char *USmlGetTag(SPLF_HANDLE hFSpool, char const *pszTagName, TAG_POSITION & TagPosition);
+int USmlGetMsgFileSection(SPLF_HANDLE hFSpool, FileSection &FSect);
+int USmlWriteMailFile(SPLF_HANDLE hFSpool, FILE *pMsgFile);
+char *USmlGetTag(SPLF_HANDLE hFSpool, char const *pszTagName, TAG_POSITION &TagPosition);
 int USmlAddTag(SPLF_HANDLE hFSpool, char const *pszTagName,
 	       char const *pszTagData, int iUpdate = 0);
 int USmlSetTagAddress(SPLF_HANDLE hFSpool, char const *pszTagName, char const *pszAddress);
 int USmlMapAddress(char const *pszAddress, char *pszDomain, char *pszName);
-int USmlCreateMBFile(UserInfo * pUI, char const *pszFileName, SPLF_HANDLE hFSpool);
+int USmlCreateMBFile(UserInfo *pUI, char const *pszFileName, SPLF_HANDLE hFSpool);
 int USmlVCreateSpoolFile(SPLF_HANDLE hFSpool, char const *pszFromUser,
 			 char const *pszRcptUser, char const *pszFileName, va_list Headers);
 int USmlCreateSpoolFile(SPLF_HANDLE hFSpool, char const *pszFromUser,
 			char const *pszRcptUser, char const *pszFileName, ...);
-int USmlProcessLocalUserMessage(SVRCFG_HANDLE hSvrConfig, UserInfo * pUI, SPLF_HANDLE hFSpool,
+int USmlProcessLocalUserMessage(SVRCFG_HANDLE hSvrConfig, UserInfo *pUI, SPLF_HANDLE hFSpool,
 				QUEUE_HANDLE hQueue, QMSG_HANDLE hMessage,
-				LocalMailProcConfig & LMPC);
+				LocalMailProcConfig &LMPC);
 int USmlGetDomainCustomDir(char *pszCustomDir, int iMaxPath, int iFinalSlash);
 int USmlGetCmdAliasDir(char *pszAliasDir, int iMaxPath, int iFinalSlash);
 int USmlGetCmdAliasFile(char const *pszDomain, char const *pszUser, char *pszAliasFile);
@@ -111,7 +112,10 @@ int USmlGetDomainMsgCustomFile(SPLF_HANDLE hFSpool, QUEUE_HANDLE hQueue,
 int USmlGetCustomDomainFile(char const *pszDestDomain, char const *pszCustFilePath);
 int USmlSetCustomDomainFile(char const *pszDestDomain, char const *pszCustFilePath);
 int USmlCustomizedDomain(char const *pszDestDomain);
-int USmlLogMessage(SPLF_HANDLE hFSpool, char const *pszMedium, char const *pszParam);
+int USmlLogMessage(SPLF_HANDLE hFSpool, char const *pszMedium, char const *pszRmtMsgID,
+		   char const *pszParam);
+int USmlValidAddress(char const *pszAddress, char const *pszTop);
+int USmlValidHost(char const *pszHost, char const *pszTop);
 int USmlParseAddress(char const *pszAddress, char *pszPreAddr,
 		     int iMaxPreAddress, char *pszEmailAddr, int iMaxAddress);
 int USmlDeliverFetchedMsg(char const *pszSyncAddr, const char *pszFetchHdrTags,
