@@ -38,6 +38,9 @@
 #define DEFAULT_SMTP_ERR            "417 Temporary delivery error"
 #define SMTP_SERVER_VARNAME         "SMTP-Server"
 
+#define SMTP_GWF_USE_TLS            (1 << 0)
+#define SMTP_GWF_FORCE_TLS          (1 << 1)
+
 typedef struct MXS_HANDLE_struct {
 } *MXS_HANDLE;
 
@@ -50,27 +53,38 @@ struct SMTPError {
 	char *pszSTMPResponse;
 };
 
+struct SMTPGateway {
+	char *pszHost;
+	char *pszIFace;
+	unsigned long ulFlags;
+};
+
 enum SmtpMsgInfo {
 	smsgiClientDomain = 0,
-	smsgiClientAddr,
-	smsgiServerDomain,
-	smsgiServerAddr,
-	smsgiTime,
-	smsgiSeverName,
+		smsgiClientAddr,
+		smsgiServerDomain,
+		smsgiServerAddr,
+		smsgiTime,
+		smsgiSeverName,
 
-	smsgiMax
+		smsgiMax
 };
 
 enum SpoolMsgInfo {
 	smiClientAddr,
-	smiServerAddr,
-	smiTime,
+		smiServerAddr,
+		smiTime,
 
-	smiMax
+		smiMax
 };
 
-char **USmtpGetFwdGateways(SVRCFG_HANDLE hSvrConfig, const char *pszDomain);
-int USmtpGetGateway(SVRCFG_HANDLE hSvrConfig, const char *pszDomain, char *pszGateway);
+SMTPGateway **USmtpMakeGateways(char const * const *ppszGwHosts, char const **ppszOptions);
+void USmtpFreeGateways(SMTPGateway **ppGws);
+SMTPGateway **USmtpGetCfgGateways(SVRCFG_HANDLE hSvrConfig,  char const * const *ppszGwHosts,
+				  const char *pszOptions);
+SMTPGateway **USmtpGetFwdGateways(SVRCFG_HANDLE hSvrConfig, const char *pszDomain);
+int USmtpGetGateway(SVRCFG_HANDLE hSvrConfig, const char *pszDomain, char *pszGateway,
+		    int iSize);
 int USmtpAddGateway(const char *pszDomain, const char *pszGateway);
 int USmtpRemoveGateway(const char *pszDomain);
 int USmtpIsAllowedRelay(const SYS_INET_ADDR & PeerInfo, SVRCFG_HANDLE hSvrConfig);
@@ -78,36 +92,42 @@ char **USmtpGetPathStrings(const char *pszMailCmd);
 int USmtpSplitEmailAddr(const char *pszAddr, char *pszUser, char *pszDomain);
 int USmtpCheckAddressPart(char const *pszName);
 int USmtpCheckAddress(char const *pszAddress);
-int USmtpInitError(SMTPError * pSMTPE);
+int USmtpInitError(SMTPError *pSMTPE);
+int USmtpSetError(SMTPError *pSMTPE, int iSTMPResponse, char const *pszSTMPResponse,
+		  char const *pszServer);
 bool USmtpIsFatalError(SMTPError const *pSMTPE);
 char const *USmtpGetErrorMessage(SMTPError const *pSMTPE);
-int USmtpCleanupError(SMTPError * pSMTPE);
-char *USmtpGetSMTPError(SMTPError * pSMTPE, char *pszError, int iMaxError);
+int USmtpCleanupError(SMTPError *pSMTPE);
+char *USmtpGetSMTPError(SMTPError *pSMTPE, char *pszError, int iMaxError);
+char *USmtpGetSMTPRmtMsgID(char const *pszAckDATA, char *pszRmtMsgID, int iMaxMsg);
 char const *USmtpGetErrorServer(SMTPError const *pSMTPE);
-SMTPCH_HANDLE USmtpCreateChannel(const char *pszServer, const char *pszDomain,
-				 SMTPError * pSMTPE = NULL);
-int USmtpCloseChannel(SMTPCH_HANDLE hSmtpCh, int iHardClose = 0, SMTPError * pSMTPE = NULL);
-int USmtpChannelReset(SMTPCH_HANDLE hSmtpCh, SMTPError * pSMTPE = NULL);
+SMTPCH_HANDLE USmtpCreateChannel(SMTPGateway const *pGw, const char *pszDomain,
+				 SMTPError *pSMTPE = NULL);
+int USmtpCloseChannel(SMTPCH_HANDLE hSmtpCh, int iHardClose = 0, SMTPError *pSMTPE = NULL);
+int USmtpChannelReset(SMTPCH_HANDLE hSmtpCh, SMTPError *pSMTPE = NULL);
 int USmtpSendMail(SMTPCH_HANDLE hSmtpCh, const char *pszFrom, const char *pszRcpt,
-		  FileSection const *pFS, SMTPError * pSMTPE = NULL);
-int USmtpSendMail(const char *pszServer, const char *pszDomain,
-		  const char *pszFrom, const char *pszRcpt, FileSection const *pFS,
-		  SMTPError * pSMTPE = NULL);
+		  FileSection const *pFS, SMTPError *pSMTPE = NULL);
+int USmtpSendMail(SMTPGateway const *pGw, const char *pszDomain, const char *pszFrom,
+		  const char *pszRcpt, FileSection const *pFS, SMTPError *pSMTPE = NULL);
+int USmtpMailRmtDeliver(SVRCFG_HANDLE hSvrConfig, const char *pszServer, const char *pszDomain,
+			const char *pszFrom, const char *pszRcpt, FileSection const *pFS,
+			SMTPError *pSMTPE = NULL);
 char *USmtpBuildRcptPath(char const *const *ppszRcptTo, SVRCFG_HANDLE hSvrConfig);
-char **USmtpGetMailExchangers(SVRCFG_HANDLE hSvrConfig, const char *pszDomain);
+SMTPGateway **USmtpGetMailExchangers(SVRCFG_HANDLE hSvrConfig, const char *pszDomain);
 int USmtpCheckMailDomain(SVRCFG_HANDLE hSvrConfig, char const *pszDomain);
 MXS_HANDLE USmtpGetMXFirst(SVRCFG_HANDLE hSvrConfig, const char *pszDomain, char *pszMXHost);
 int USmtpGetMXNext(MXS_HANDLE hMXSHandle, char *pszMXHost);
 void USmtpMXSClose(MXS_HANDLE hMXSHandle);
-bool USmtpDnsMapsContained(SYS_INET_ADDR const &PeerInfo, char const *pszMapsServer);
+int USmtpDnsMapsContained(SYS_INET_ADDR const &PeerInfo, char const *pszMapsServer);
 int USmtpSpammerCheck(const SYS_INET_ADDR & PeerInfo, char *&pszInfo);
 int USmtpSpamAddressCheck(char const *pszAddress);
-int USmtpAddMessageInfo(FILE * pMsgFile, char const *pszClientDomain,
+int USmtpAddMessageInfo(FILE *pMsgFile, char const *pszClientDomain,
 			SYS_INET_ADDR const &PeerInfo, char const *pszServerDomain,
 			SYS_INET_ADDR const &SockInfo, char const *pszSmtpServerLogo);
-int USmtpWriteInfoLine(FILE * pSpoolFile, char const *pszClientAddr,
+int USmtpWriteInfoLine(FILE *pSpoolFile, char const *pszClientAddr,
 		       char const *pszServerAddr, char const *pszTime);
 char *USmtpGetReceived(int iType, char const *pszAuth, char const *const *ppszMsgInfo,
 		       char const *pszMailFrom, char const *pszRcptTo, char const *pszMessageID);
 
 #endif
+
