@@ -29,26 +29,37 @@
 #define LoChar(c)           ((((c) >= 'A') && ((c) <= 'Z')) ? ((c) - 'A' + 'a'): (c))
 #define MIN_DYNSTR_INCR     256
 
+void *StrMemDup(void const *pData, long lSize, long lExtra)
+{
+	void *pDData;
+
+	if (lSize < 0)
+		lSize = strlen((char const *) pData) + 1;
+	if ((pDData = SysAllocNZ(lSize + lExtra)) == NULL)
+		return NULL;
+	memcpy(pDData, pData, lSize);
+	memset((char *) pDData + lSize, 0, lExtra);
+
+	return pDData;
+}
+
 int StrCmdLineToken(char const *&pszCmdLine, char *pszToken)
 {
-
 	char const *pszCurr = pszCmdLine;
 
 	for (; (*pszCurr == ' ') || (*pszCurr == '\t'); pszCurr++);
 
 	if (*pszCurr == '\0')
-		return (ERR_NO_MORE_TOKENS);
+		return ERR_NO_MORE_TOKENS;
 
 	if (*pszCurr == '"') {
 		++pszCurr;
-
 		for (; *pszCurr != '\0';) {
 			if (*pszCurr == '"') {
 				++pszCurr;
 
 				if (*pszCurr != '"')
 					break;
-
 				*pszToken++ = *pszCurr++;
 			} else
 				*pszToken++ = *pszCurr++;
@@ -61,16 +72,13 @@ int StrCmdLineToken(char const *&pszCmdLine, char *pszToken)
 
 		*pszToken = '\0';
 	}
-
 	pszCmdLine = pszCurr;
 
-	return (0);
-
+	return 0;
 }
 
 char **StrGetArgs(char const *pszCmdLine, int &iArgsCount)
 {
-
 	char const *pszCLine = pszCmdLine;
 	char szToken[1024] = "";
 
@@ -79,100 +87,89 @@ char **StrGetArgs(char const *pszCmdLine, int &iArgsCount)
 	char **ppszArgs = (char **) SysAlloc((iArgsCount + 1) * sizeof(char *));
 
 	if (ppszArgs == NULL)
-		return (NULL);
+		return NULL;
 
-	int ii = 0;
+	int i = 0;
 
 	for (pszCLine = pszCmdLine;
-	     (ii < iArgsCount) && (StrCmdLineToken(pszCLine, szToken) == 0); ii++)
-		ppszArgs[ii] = SysStrDup(szToken);
+	     (i < iArgsCount) && (StrCmdLineToken(pszCLine, szToken) == 0); i++)
+		ppszArgs[i] = SysStrDup(szToken);
 
-	ppszArgs[ii] = NULL;
-
-	return (ppszArgs);
+	ppszArgs[i] = NULL;
 
+	return ppszArgs;
 }
 
 char *StrLower(char *pszString)
 {
-
 	char *pszCurr = pszString;
 
 	for (; *pszCurr != '\0'; pszCurr++)
 		if ((*pszCurr >= 'A') && (*pszCurr <= 'Z'))
 			*pszCurr = 'a' + (*pszCurr - 'A');
 
-	return (pszString);
-
+	return pszString;
 }
 
 char *StrUpper(char *pszString)
 {
-
 	char *pszCurr = pszString;
 
 	for (; *pszCurr != '\0'; pszCurr++)
 		if ((*pszCurr >= 'a') && (*pszCurr <= 'z'))
 			*pszCurr = 'A' + (*pszCurr - 'a');
 
-	return (pszString);
-
+	return pszString;
 }
 
 char *StrCrypt(char const *pszString, char *pszCrypt)
 {
-
 	SetEmptyString(pszCrypt);
 
-	for (int ii = 0; pszString[ii] != '\0'; ii++) {
-		unsigned int uChar = (unsigned int) pszString[ii];
+	for (int i = 0; pszString[i] != '\0'; i++) {
+		unsigned int uChar = (unsigned int) pszString[i];
 		char szByte[32] = "";
 
 		sprintf(szByte, "%02x", (uChar ^ 101) & 0xff);
-
 		strcat(pszCrypt, szByte);
 	}
 
-	return (pszCrypt);
-
+	return pszCrypt;
 }
 
 char *StrDeCrypt(char const *pszString, char *pszDeCrypt)
 {
-
 	int iStrLength = strlen(pszString);
 
 	SetEmptyString(pszDeCrypt);
 
 	if ((iStrLength % 2) != 0)
-		return (NULL);
+		return NULL;
 
-	int ii;
+	int i;
 
-	for (ii = 0; ii < iStrLength; ii += 2) {
+	for (i = 0; i < iStrLength; i += 2) {
 		char szByte[8] = "";
 
-		szByte[0] = pszString[ii];
-		szByte[1] = pszString[ii + 1];
+		szByte[0] = pszString[i];
+		szByte[1] = pszString[i + 1];
 		szByte[2] = '\0';
 
 		unsigned int uChar = 0;
 
 		if (sscanf(szByte, "%x", &uChar) != 1)
-			return (NULL);
+			return NULL;
 
-		pszDeCrypt[ii >> 1] = (char) ((uChar ^ 101) & 0xff);
+		pszDeCrypt[i >> 1] = (char) ((uChar ^ 101) & 0xff);
 	}
 
-	pszDeCrypt[ii >> 1] = '\0';
-
-	return (pszDeCrypt);
+	pszDeCrypt[i >> 1] = '\0';
 
+	return pszDeCrypt;
 }
 
 char **StrBuildList(char const *pszString, ...)
 {
-
 	int iNumString = 1;
 	char const *pszArg = NULL;
 	va_list Args;
@@ -188,30 +185,28 @@ char **StrBuildList(char const *pszString, ...)
 	char **ppszStrings = (char **) SysAlloc((iNumString + 1) * sizeof(char *));
 
 	if (ppszStrings == NULL)
-		return (NULL);
+		return NULL;
 
 	ppszStrings[iStrCurr++] = SysStrDup(pszString);
 
 	va_start(Args, pszString);
 
 	while ((pszArg = va_arg(Args, char *)) != NULL)
-		 ppszStrings[iStrCurr++] = SysStrDup(pszArg);
+		ppszStrings[iStrCurr++] = SysStrDup(pszArg);
 
 	va_end(Args);
 
 	ppszStrings[iStrCurr] = NULL;
 
-	return (ppszStrings);
-
+	return ppszStrings;
 }
 
 char **StrTokenize(const char *pszString, const char *pszTokenizer)
 {
-
 	char *pszBuffer = SysStrDup(pszString);
 
 	if (pszBuffer == NULL)
-		return (NULL);
+		return NULL;
 
 	int iTokenCount = 0;
 	char *pszToken = NULL;
@@ -229,7 +224,7 @@ char **StrTokenize(const char *pszString, const char *pszTokenizer)
 
 	if (ppszTokens == NULL) {
 		SysFree(pszBuffer);
-		return (NULL);
+		return NULL;
 	}
 
 	strcpy(pszBuffer, pszString);
@@ -242,172 +237,156 @@ char **StrTokenize(const char *pszString, const char *pszTokenizer)
 
 		pszToken = SysStrTok(NULL, pszTokenizer, &pszSavePtr);
 	}
-
 	ppszTokens[iTokenCount] = NULL;
-
 	SysFree(pszBuffer);
 
-	return (ppszTokens);
-
+	return ppszTokens;
 }
 
 void StrFreeStrings(char **ppszStrings)
 {
-
-	for (int ii = 0; ppszStrings[ii] != NULL; ii++)
-		SysFree(ppszStrings[ii]);
-
+	if (ppszStrings != NULL)
+		for (int i = 0; ppszStrings[i] != NULL; i++)
+			SysFree(ppszStrings[i]);
 	SysFree(ppszStrings);
-
 }
 
 int StrStringsCount(char const *const *ppszStrings)
 {
+	int i;
 
-	int ii;
-
-	for (ii = 0; ppszStrings[ii] != NULL; ii++);
-
-	return (ii);
+	for (i = 0; ppszStrings[i] != NULL; i++);
 
+	return i;
 }
 
 bool StrStringsMatch(char const *const *ppszStrings, char const *pszMatch)
 {
+	int i;
 
-	int ii;
-
-	for (ii = 0; ppszStrings[ii] != NULL; ii++)
-		if (strcmp(ppszStrings[ii], pszMatch) == 0)
-			return (true);
-
-	return (false);
+	for (i = 0; ppszStrings[i] != NULL; i++)
+		if (strcmp(ppszStrings[i], pszMatch) == 0)
+			return true;
 
+	return false;
 }
 
 bool StrStringsIMatch(char const *const *ppszStrings, char const *pszMatch)
 {
+	int i;
 
-	int ii;
-
-	for (ii = 0; ppszStrings[ii] != NULL; ii++)
-		if (stricmp(ppszStrings[ii], pszMatch) == 0)
-			return (true);
-
-	return (false);
+	for (i = 0; ppszStrings[i] != NULL; i++)
+		if (stricmp(ppszStrings[i], pszMatch) == 0)
+			return true;
 
+	return false;
 }
 
 bool StrStringsRIWMatch(char const *const *pszMatches, char const *pszString)
 {
+	int i;
 
-	int ii;
-
-	for (ii = 0; pszMatches[ii] != NULL; ii++)
-		if (StrIWildMatch(pszString, pszMatches[ii]))
-			return (true);
-
-	return (false);
+	for (i = 0; pszMatches[i] != NULL; i++)
+		if (StrIWildMatch(pszString, pszMatches[i]))
+			return true;
 
+	return false;
 }
 
 char *StrConcat(char const *const *ppszStrings, char const *pszCStr)
 {
-
-	int ii;
+	int i;
 	int iStrCount = StrStringsCount(ppszStrings);
 	int iCStrLength = strlen(pszCStr);
 	int iSumLength = 0;
 
-	for (ii = 0; ii < iStrCount; ii++)
-		iSumLength += strlen(ppszStrings[ii]) + iCStrLength;
+	for (i = 0; i < iStrCount; i++)
+		iSumLength += strlen(ppszStrings[i]) + iCStrLength;
 
 	char *pszConcat = (char *) SysAlloc(iSumLength + 1);
 
 	if (pszConcat == NULL)
-		return (NULL);
+		return NULL;
 
 	SetEmptyString(pszConcat);
-
-	for (ii = 0; ii < iStrCount; ii++) {
-		if (ii > 0)
+	for (i = 0; i < iStrCount; i++) {
+		if (i > 0)
 			strcat(pszConcat, pszCStr);
-
-		strcat(pszConcat, ppszStrings[ii]);
+		strcat(pszConcat, ppszStrings[i]);
 	}
 
-	return (pszConcat);
-
+	return pszConcat;
 }
 
 char *StrDeQuote(char *pszString, int iChar)
 {
-
 	if (*pszString == iChar) {
-		int ii;
+		int i, j;
 
-		for (ii = 1; (pszString[ii] != '\0') && (pszString[ii] != iChar); ii++)
-			pszString[ii - 1] = pszString[ii];
-
-		pszString[ii - 1] = '\0';
+		for (i = 1, j = 0; pszString[i] != '\0' && pszString[i] != iChar; i++) {
+			if (pszString[i] == '\\' && pszString[i + 1] == iChar)
+				i++;
+			pszString[j++] = pszString[i];
+		}
+		pszString[j] = '\0';
 	}
 
-	return (pszString);
-
+	return pszString;
 }
 
 char *StrQuote(const char *pszString, int iChar)
 {
+	int i, j, iQSize;
 
-	int iStrLen = strlen(pszString);
-	char *pszBuffer = (char *) SysAlloc(3 + iStrLen);
+	for (i = iQSize = 0; pszString[i] != '\0'; i++, iQSize++)
+		if (pszString[i] == iChar)
+			iQSize++;
+
+	char *pszBuffer = (char *) SysAlloc(3 + iQSize);
 
 	if (pszBuffer == NULL)
-		return (NULL);
+		return NULL;
 
 	pszBuffer[0] = (char) iChar;
-	memcpy(pszBuffer + 1, pszString, iStrLen);
-	pszBuffer[iStrLen + 1] = (char) iChar;
-	pszBuffer[iStrLen + 2] = '\0';
-
-	return (pszBuffer);
+	for (i = 0, j = 1; pszString[i] != '\0'; i++) {
+		if (pszString[i] == iChar)
+			pszBuffer[j++] = '\\';
+		pszBuffer[j++] = pszString[i];
+	}
+	pszBuffer[j++] = (char) iChar;
+	pszBuffer[j] = '\0';
 
+	return pszBuffer;
 }
 
 char **StrGetTabLineStrings(const char *pszUsrLine)
 {
-
 	char **ppszStrings = StrTokenize(pszUsrLine, "\t");
 
 	if (ppszStrings == NULL)
-		return (NULL);
+		return NULL;
 
-	for (int ii = 0; ppszStrings[ii] != NULL; ii++)
-		StrDeQuote(ppszStrings[ii], '"');
-
-	return (ppszStrings);
+	for (int i = 0; ppszStrings[i] != NULL; i++)
+		StrDeQuote(ppszStrings[i], '"');
 
+	return ppszStrings;
 }
 
-int StrWriteCRLFString(FILE * pFile, const char *pszString)
+int StrWriteCRLFString(FILE *pFile, const char *pszString)
 {
-
 	unsigned int uStrLength = strlen(pszString);
 
-	if ((uStrLength != 0) && (fwrite(pszString, uStrLength, 1, pFile) == 0)) {
+	if (uStrLength != 0 && fwrite(pszString, uStrLength, 1, pFile) == 0) {
 		ErrSetErrorCode(ERR_FILE_WRITE);
-		return (ERR_FILE_WRITE);
+		return ERR_FILE_WRITE;
 	}
-
 	fputs("\r\n", pFile);
 
-	return (0);
-
+	return 0;
 }
 
 int StrWildMatch(char const *pszString, char const *pszMatch)
 {
-
 	int iPrev;
 	int iMatched;
 	int iReverse;
@@ -417,26 +396,26 @@ int StrWildMatch(char const *pszString, char const *pszMatch)
 		switch (*pszMatch) {
 		case ('\\'):
 			if (!*++pszMatch)
-				return (0);
+				return 0;
 
 		default:
 			if (*pszString != *pszMatch)
-				return (0);
+				return 0;
 			continue;
 
 		case ('?'):
 			if (*pszString == '\0')
-				return (0);
+				return 0;
 			continue;
 
 		case ('*'):
 			while (*(++pszMatch) == '*');
 			if (!*pszMatch)
-				return (1);
+				return 1;
 			while (*pszString)
 				if (StrWildMatch(pszString++, pszMatch))
-					return (1);
-			return (0);
+					return 1;
+			return 0;
 
 		case ('['):
 			iEscape = 0;
@@ -450,10 +429,10 @@ int StrWildMatch(char const *pszString, char const *pszMatch)
 					continue;
 				if (!iEscape && (*pszMatch == '-')) {
 					if (!*++pszMatch)
-						return (0);
+						return 0;
 					if (*pszMatch == '\\')
 						if (!*++pszMatch)
-							return (0);
+							return 0;
 					iMatched = iMatched || ((*pszString <= *pszMatch) &&
 								(*pszString >= iPrev));
 				} else
@@ -461,31 +440,29 @@ int StrWildMatch(char const *pszString, char const *pszMatch)
 				iEscape = 0;
 			}
 
-			if ((iPrev == 256) || iEscape || (*pszMatch != ']') ||
-			    (iMatched == iReverse))
-				return (0);
+			if (iPrev == 256 || iEscape || *pszMatch != ']' ||
+			    iMatched == iReverse)
+				return 0;
 
 			continue;
 		}
 	}
 
-	return ((*pszString == '\0') ? 1 : 0);
-
+	return (*pszString == '\0') ? 1 : 0;
 }
 
 int StrIWildMatch(char const *pszString, char const *pszMatch)
 {
-
 	char *pszLowString = SysStrDup(pszString);
 
 	if (pszLowString == NULL)
-		return (0);
+		return 0;
 
 	char *pszLowMatch = SysStrDup(pszMatch);
 
 	if (pszLowMatch == NULL) {
 		SysFree(pszLowString);
-		return (0);
+		return 0;
 	}
 
 	StrLower(pszLowString);
@@ -496,49 +473,42 @@ int StrIWildMatch(char const *pszString, char const *pszMatch)
 	SysFree(pszLowMatch);
 	SysFree(pszLowString);
 
-	return (iMatchResult);
-
+	return iMatchResult;
 }
 
-char *StrLoadFile(FILE * pFile)
+char *StrLoadFile(FILE *pFile)
 {
-
 	fseek(pFile, 0, SEEK_END);
 
 	unsigned int uFileSize = (unsigned int) ftell(pFile);
 	char *pszData = (char *) SysAlloc(uFileSize + 1);
 
 	if (pszData == NULL)
-		return (NULL);
+		return NULL;
 
 	fseek(pFile, 0, SEEK_SET);
 
 	fread(pszData, uFileSize, 1, pFile);
 	pszData[uFileSize] = '\0';
 
-	return (pszData);
-
+	return pszData;
 }
 
 char *StrSprint(char const *pszFormat, ...)
 {
-
 	char *pszMessage = NULL;
 
-	STRSPRINTF(pszMessage, pszFormat, pszFormat);
-
-	return (pszMessage);
+	StrVSprint(pszMessage, pszFormat, pszFormat);
 
+	return pszMessage;
 }
 
 int StrSplitString(char const *pszString, char const *pszSplitters,
 		   char *pszStrLeft, int iSizeLeft, char *pszStrRight, int iSizeRight)
 {
-
 	char const *pszSplitChar = NULL;
 
-	for (;
-	     (*pszSplitters != '\0') &&
+	for (; (*pszSplitters != '\0') &&
 	     ((pszSplitChar = strchr(pszString, *pszSplitters)) == NULL); ++pszSplitters);
 
 	if (pszSplitChar == NULL) {
@@ -553,181 +523,215 @@ int StrSplitString(char const *pszString, char const *pszSplitters,
 
 			StrNCpy(pszStrLeft, pszString, Min(iUserLength + 1, iSizeLeft));
 		}
-
 		if (pszStrRight != NULL)
 			StrNCpy(pszStrRight, pszSplitChar + 1, iSizeRight);
 	}
 
-	return (0);
-
+	return 0;
 }
 
 char *StrLTrim(char *pszString, char const *pszTrimChars)
 {
+	int i;
 
-	int ii;
+	for (i = 0; (pszString[i] != '\0') && (strchr(pszTrimChars, pszString[i]) != NULL);
+	     i++);
 
-	for (ii = 0; (pszString[ii] != '\0') && (strchr(pszTrimChars, pszString[ii]) != NULL);
-	     ii++);
+	if (i > 0 && pszString[i] != '\0') {
+		int j;
 
-	if ((ii > 0) && (pszString[ii] != '\0')) {
-		int jj;
+		for (j = i; pszString[j] != '\0'; j++)
+			pszString[j - i] = pszString[j];
 
-		for (jj = ii; pszString[jj] != '\0'; jj++)
-			pszString[jj - ii] = pszString[jj];
-
-		pszString[jj - ii] = pszString[jj];
+		pszString[j - i] = pszString[j];
 	}
 
-	return (pszString);
-
+	return pszString;
 }
 
 char *StrRTrim(char *pszString, char const *pszTrimChars)
 {
+	int i = strlen(pszString) - 1;
 
-	int ii = strlen(pszString) - 1;
-
-	for (; (ii >= 0) && (strchr(pszTrimChars, pszString[ii]) != NULL); ii--)
-		pszString[ii] = '\0';
-
-	return (pszString);
+	for (; i >= 0 && strchr(pszTrimChars, pszString[i]) != NULL; i--)
+		pszString[i] = '\0';
 
+	return pszString;
 }
 
 char *StrTrim(char *pszString, char const *pszTrimChars)
 {
-
-	return (StrRTrim(StrLTrim(pszString, pszTrimChars), pszTrimChars));
-
-}
-
-char *StrEOLTrim(char *pszString)
-{
-
-	int iPos = strlen(pszString);
-
-	for (; (iPos > 0) && ((pszString[iPos - 1] == '\r') || (pszString[iPos - 1] == '\n'));
-	     iPos--);
-
-	pszString[iPos] = '\0';
-
-	return (pszString);
-
+	return StrRTrim(StrLTrim(pszString, pszTrimChars), pszTrimChars);
 }
 
 char *StrIStr(char const *pszBuffer, char const *pszMatch)
 {
-
 	int iMatchLen = strlen(pszMatch);
 	int iMatchPos = 0;
 	int iLoMatch = LoChar(*pszMatch);
 
 	if (iMatchLen == 0)
-		return ((char *) pszBuffer);
+		return (char *) pszBuffer;
 
+	/*
+	 * The dumb algorithm is fine enough.
+	 */
 	for (; *pszBuffer != '\0'; pszBuffer++) {
 		if (LoChar(*pszBuffer) == iLoMatch) {
 			if (++iMatchPos == iMatchLen)
-				return ((char *) pszBuffer - iMatchLen + 1);
+				return (char *) pszBuffer - iMatchLen + 1;
 
 			iLoMatch = LoChar(pszMatch[iMatchPos]);
 		} else if (iMatchPos != 0) {
 			iMatchPos = 0;
-
 			iLoMatch = LoChar(*pszMatch);
 		}
 	}
 
-	return (NULL);
-
+	return NULL;
 }
 
-int StrDynInit(DynString * pDS)
+char *StrLimStr(char const *pszBuffer, char const *pszMatch, char const *pszLimits)
 {
+	int iMatchLen = strlen(pszMatch);
+	char const *pszPos;
+
+	for (pszPos = strstr(pszBuffer, pszMatch); pszPos != NULL;
+	     pszPos = strstr(pszBuffer, pszMatch)) {
+		if ((pszBuffer == (char const *) pszPos ||
+		     strchr(pszLimits, *pszPos) != NULL) &&
+		    (pszPos[iMatchLen] == '\0' ||
+		     strchr(pszLimits, pszPos[iMatchLen]) != NULL))
+			return (char *) pszPos;
+		pszBuffer = pszPos + iMatchLen;
+	}
+
+	return NULL;
+}
+
+char *StrLimIStr(char const *pszBuffer, char const *pszMatch, char const *pszLimits)
+{
+	int iMatchLen = strlen(pszMatch);
+	char *pszPos;
+
+	for (pszPos = StrIStr(pszBuffer, pszMatch); pszPos != NULL;
+	     pszPos = StrIStr(pszBuffer, pszMatch)) {
+		if ((pszBuffer == (char const *) pszPos ||
+		     strchr(pszLimits, *pszPos) != NULL) &&
+		    (pszPos[iMatchLen] == '\0' ||
+		     strchr(pszLimits, pszPos[iMatchLen]) != NULL))
+			return pszPos;
+		pszBuffer = pszPos + iMatchLen;
+	}
+
+	return NULL;
+}
+
+int StrDynInit(DynString *pDS, char const *pszInit)
+{
+	if (pszInit == NULL)
+		pszInit = "";
+
+	int iInitLength = strlen(pszInit);
 
 	ZeroData(*pDS);
-	pDS->pszBuffer = SysStrDup("");
-	pDS->iStringSize = 0;
-	pDS->iBufferSize = 0;
+	pDS->iStringSize = iInitLength;
+	pDS->iBufferSize = Max(2 * iInitLength, MIN_DYNSTR_INCR);
 
-	return (0);
+	if ((pDS->pszBuffer = (char *) SysAlloc(pDS->iBufferSize)) == NULL)
+		return ErrGetErrorCode();
+	memcpy(pDS->pszBuffer, pszInit, iInitLength);
 
+	return 0;
 }
 
-int StrDynFree(DynString * pDS)
+int StrDynFree(DynString *pDS)
 {
+	SysFree(pDS->pszBuffer);
 
-	if (pDS->pszBuffer != NULL)
-		SysFree(pDS->pszBuffer);
-
-	ZeroData(*pDS);
-
-	return (0);
-
+	return 0;
 }
 
-int StrDynTruncate(DynString * pDS)
+int StrDynTruncate(DynString *pDS)
 {
-
-	if (pDS->pszBuffer != NULL)
-		SetEmptyString(pDS->pszBuffer);
-
 	pDS->iStringSize = 0;
 
-	return (0);
-
+	return 0;
 }
 
-char const *StrDynGet(DynString * pDS)
+char const *StrDynGet(DynString *pDS)
 {
+	pDS->pszBuffer[pDS->iStringSize] = '\0';
 
-	return (pDS->pszBuffer);
-
+	return pDS->pszBuffer;
 }
 
-int StrDynSize(DynString * pDS)
+char *StrDynDrop(DynString *pDS, int *piSize)
 {
+	char *pszBuffer = pDS->pszBuffer;
 
-	return (pDS->iStringSize);
+	if (piSize != NULL)
+		*piSize = pDS->iStringSize;
+	pszBuffer[pDS->iStringSize] = '\0';
+	pDS->pszBuffer = NULL;
 
+	return pszBuffer;
 }
 
-int StrDynAdd(DynString * pDS, char const *pszBuffer, int iStringSize)
+int StrDynSize(DynString *pDS)
 {
+	return pDS->iStringSize;
+}
 
+int StrDynAdd(DynString *pDS, char const *pszBuffer, int iStringSize)
+{
 	if (iStringSize < 0)
 		iStringSize = strlen(pszBuffer);
-
 	if ((pDS->iStringSize + iStringSize) >= pDS->iBufferSize) {
 		int iNewSize = pDS->iBufferSize + Max(2 * iStringSize, MIN_DYNSTR_INCR);
 		char *pszNewBuffer = (char *) SysAlloc(iNewSize);
 
 		if (pszNewBuffer == NULL)
-			return (ErrGetErrorCode());
-
-		strcpy(pszNewBuffer, pDS->pszBuffer);
+			return ErrGetErrorCode();
 
+		memcpy(pszNewBuffer, pDS->pszBuffer, pDS->iStringSize);
 		SysFree(pDS->pszBuffer);
-
 		pDS->pszBuffer = pszNewBuffer;
-
 		pDS->iBufferSize = iNewSize;
 	}
-
 	memcpy(pDS->pszBuffer + pDS->iStringSize, pszBuffer, iStringSize);
-
 	pDS->iStringSize += iStringSize;
 
-	pDS->pszBuffer[pDS->iStringSize] = '\0';
+	return 0;
+}
 
-	return (0);
+int StrDynPrint(DynString *pDS, char const *pszFormat, ...)
+{
+	char *pszMessage = NULL;
 
+	StrVSprint(pszMessage, pszFormat, pszFormat);
+	if (pszMessage == NULL)
+		return ErrGetErrorCode();
+
+	int iAddResult = StrDynAdd(pDS, pszMessage);
+
+	SysFree(pszMessage);
+
+	return iAddResult;
+}
+
+char *StrNDup(char const *pszStr, int iSize)
+{
+	char *pszDupStr = (char *) SysAlloc(iSize + 1);
+
+	if (pszDupStr != NULL)
+		Cpy2Sz(pszDupStr, pszStr, iSize);
+
+	return pszDupStr;
 }
 
 int StrParamGet(char const *pszBuffer, char const *pszName, char *pszVal, int iMaxVal)
 {
-
 	int iNameLen = strlen(pszName), iParamSize;
 	char const *pszTmp, *pszEnd;
 
@@ -744,10 +748,57 @@ int StrParamGet(char const *pszBuffer, char const *pszName, char *pszVal, int iM
 
 		Cpy2Sz(pszVal, pszTmp, iParamSize);
 
-		return (1);
+		return 1;
 	}
 
-	return (0);
+	return 0;
+}
 
+char *StrMacSubst(char const *pszIn, int *piSize,
+		  char *(*pLkupProc)(void *, char const *, int), void *pPriv)
+{
+	int i, j;
+	char *pszLkup = NULL;
+	char const *pszVarS, *pszVarE;
+	DynString DynS;
+	char szBuf[128];
+
+	if (StrDynInit(&DynS, NULL) < 0)
+		return NULL;
+	for (i = j = 0; pszIn[i]; i++) {
+		if (pszIn[i] == '\\' && pszIn[i + 1] == '$')
+			szBuf[j++] = pszIn[++i];
+		else if (pszIn[i] == '$') {
+			if (pszIn[++i] != '(')
+				goto ErrorExit;
+			pszVarS = pszIn + i + 1;
+			if ((pszVarE = strchr(pszVarS, ')')) == NULL)
+				goto ErrorExit;
+			if (j && StrDynAdd(&DynS, szBuf, j) < 0)
+				goto ErrorExit;
+			j = 0;
+			if ((pszLkup = (*pLkupProc)(pPriv, pszVarS, pszVarE - pszVarS)) == NULL ||
+			    StrDynAdd(&DynS, pszLkup, -1) < 0)
+				goto ErrorExit;
+			SysFree(pszLkup);
+			pszLkup = NULL;
+			i = pszVarE - pszIn;
+		} else
+			szBuf[j++] = pszIn[i];
+		if (j == CountOf(szBuf)) {
+			if (StrDynAdd(&DynS, szBuf, j) < 0)
+				goto ErrorExit;
+			j = 0;
+		}
+	}
+	if (j && StrDynAdd(&DynS, szBuf, j) < 0)
+		goto ErrorExit;
+
+	return StrDynDrop(&DynS, piSize);
+
+	ErrorExit:
+	SysFree(pszLkup);
+	StrDynFree(&DynS);
+	return NULL;
 }
 
