@@ -24,6 +24,7 @@
 #define _SYSINCLUDEWIN_H
 
 #include <winsock2.h>
+#include <ws2tcpip.h>
 #include <mswsock.h>
 #include <windows.h>
 #include <windowsx.h>
@@ -41,5 +42,6 @@
 #include <time.h>
 #include <stdarg.h>
 #include <limits.h>
+#include <crtdbg.h>
 
 #endif
