@@ -23,6 +23,7 @@
 #include "SysInclude.h"
 #include "SysDep.h"
 #include "SvrDefines.h"
+#include "Array.h"
 #include "ShBlocks.h"
 #include "StrUtils.h"
 #include "SList.h"
@@ -30,9 +31,7 @@
 #include "MiscUtils.h"
 #include "TabIndex.h"
 
-///////////////////////////////////////////////////////////////////////////////
-//  The index version MUST be incremented at every file format change
-///////////////////////////////////////////////////////////////////////////////
+/* The index version MUST be incremented at every file format change */
 #define TAB_INDEX_CURR_VERSION      1
 
 #define TAB_SAMPLE_LINES            32
@@ -42,21 +41,23 @@
 #define KEY_BUFFER_SIZE             1024
 #define TAB_RECORD_BUFFER_SIZE      2048
 #define TOKEN_SEP_STR               "\t"
+#define TAB_INIT_RESSET_SIZE        128
+
 
 struct HashLink {
 	SysListHead LLink;
-	SYS_UINT32 uOffset;
+	TabIdxUINT uOffset;
 };
 
 struct HashNode {
 	SysListHead NodeList;
-	SYS_UINT32 uCount;
+	TabIdxUINT uCount;
 };
 
 struct HashFileHeader {
 	SYS_UINT32 uMagic;
 	SYS_UINT32 uVersion;
-	SYS_UINT32 uHashSize;
+	TabIdxUINT uHashSize;
 };
 
 struct TabHashIndex {
@@ -65,49 +66,51 @@ struct TabHashIndex {
 };
 
 struct IndexLookupData {
+	ARRAY_HANDLE hArray;
+	long lRecCount;
 	FILE *pTabFile;
-	SYS_UINT32 *pHashTable;
+	TabIdxUINT *pHTblC;
+	long lArIdx;
+	long lHTblI;
 };
 
-static int TbixCalcHashSize(FILE * pTabFile, char *pszLineBuffer, int iBufferSize);
-static int TbixFreeHash(HashNode * pHash, int iHashSize);
+static int TbixCalcHashSize(FILE *pTabFile, char *pszLineBuffer, int iBufferSize);
+static int TbixFreeHash(HashNode *pHash, int iHashSize);
 static int TbixBuildKey(char *pszKey, va_list Args, bool bCaseSens);
 static int TbixBuildKey(char *pszKey, char const *const *ppszTabTokens,
 			int const *piFieldsIdx, bool bCaseSens);
-static int TbixOpenIndex(char const *pszIndexFile, TabHashIndex & THI);
-static int TbixCloseIndex(TabHashIndex & THI);
+static TabIdxUINT TbixHashData(char const *pData, long lSize);
+static int TbixOpenIndex(char const *pszIndexFile, TabHashIndex &THI);
+static int TbixCloseIndex(TabHashIndex &THI);
 static int TbixCheckIndex(char const *pszIndexFile);
-static SYS_UINT32 *TbixReadTable(TabHashIndex & THI, SYS_UINT32 uHashVal);
-static char **TbixLoadRecord(FILE * pTabFile, SYS_UINT32 uOffset);
+static TabIdxUINT *TbixReadTable(TabHashIndex &THI, TabIdxUINT uHashVal);
+static char **TbixLoadRecord(FILE *pTabFile, TabIdxUINT uOffset);
 
-static int TbixCalcHashSize(FILE * pTabFile, char *pszLineBuffer, int iBufferSize)
+static int TbixCalcHashSize(FILE *pTabFile, char *pszLineBuffer, int iBufferSize)
 {
-
 	int iSampleLines = 0;
 	unsigned long ulOrigOffset = (unsigned long) ftell(pTabFile);
 	unsigned long ulCurrOffset = 0;
 	unsigned long ulLineSize = 0;
 
 	rewind(pTabFile);
-
 	while (iSampleLines < TAB_SAMPLE_LINES) {
 		if (MscGetString(pTabFile, pszLineBuffer, iBufferSize - 1) == NULL)
 			break;
 
 		unsigned long ulOffset = (unsigned long) ftell(pTabFile);
 
-		if (!IsEmptyString(pszLineBuffer) && (pszLineBuffer[0] != TAB_COMMENT_CHAR)) {
+		if (!IsEmptyString(pszLineBuffer) &&
+		    pszLineBuffer[0] != TAB_COMMENT_CHAR) {
 			ulLineSize += ulOffset - ulCurrOffset;
 
 			++iSampleLines;
 		}
-
 		ulCurrOffset = ulOffset;
 	}
-
 	if (iSampleLines == 0) {
 		fseek(pTabFile, ulOrigOffset, SEEK_SET);
-		return (TAB_MIN_HASH_SIZE);
+		return TAB_MIN_HASH_SIZE;
 	}
 
 	ulLineSize /= iSampleLines;
@@ -123,110 +126,89 @@ static int TbixCalcHashSize(FILE * pTabFile, char *pszLineBuffer, int iBufferSiz
 	while (!IsPrimeNumber(iHashSize))
 		++iHashSize;
 
-	return (iHashSize);
-
+	return iHashSize;
 }
 
 char *TbixGetIndexFile(char const *pszTabFilePath, int const *piFieldsIdx, char *pszIndexFile)
 {
-
 	char szFileDir[SYS_MAX_PATH] = "";
 	char szFileName[SYS_MAX_PATH] = "";
 
-	MscSplitPath(pszTabFilePath, szFileDir, szFileName, NULL);
-
+	MscSplitPath(pszTabFilePath, szFileDir, sizeof(szFileDir),
+		     szFileName, sizeof(szFileName), NULL, 0);
 	sprintf(pszIndexFile, "%s%s%s%s-", szFileDir, TAB_INDEX_DIR, SYS_SLASH_STR, szFileName);
 
-	for (int ii = 0; piFieldsIdx[ii] != INDEX_SEQUENCE_TERMINATOR; ii++) {
+	for (int i = 0; piFieldsIdx[i] != INDEX_SEQUENCE_TERMINATOR; i++) {
 		char szIndex[64] = "";
 
-		sprintf(szIndex, "%02d", piFieldsIdx[ii]);
-
+		sprintf(szIndex, "%02d", piFieldsIdx[i]);
 		strcat(pszIndexFile, szIndex);
 	}
-
 	strcat(pszIndexFile, ".hdx");
 
-	return (pszIndexFile);
-
+	return pszIndexFile;
 }
 
-static int TbixFreeHash(HashNode * pHash, int iHashSize)
+static int TbixFreeHash(HashNode *pHash, int iHashSize)
 {
-
-	for (int ii = 0; ii < iHashSize; ii++) {
-		SysListHead *pHead = &pHash[ii].NodeList;
+	for (int i = 0; i < iHashSize; i++) {
+		SysListHead *pHead = &pHash[i].NodeList;
 		SysListHead *pLLink;
 
 		while ((pLLink = SYS_LIST_FIRST(pHead)) != NULL) {
 			HashLink *pHL = SYS_LIST_ENTRY(pLLink, HashLink, LLink);
 
 			SYS_LIST_DEL(&pHL->LLink);
-
 			SysFree(pHL);
 		}
 	}
-
 	SysFree(pHash);
 
-	return (0);
-
+	return 0;
 }
 
 int TbixCreateIndex(char const *pszTabFilePath, int const *piFieldsIdx, bool bCaseSens,
-		    int (*pHashFunc) (char const *const *, int const *, SYS_UINT32 *, bool))
+		    int (*pHashFunc) (char const *const *, int const *, TabIdxUINT *, bool))
 {
-///////////////////////////////////////////////////////////////////////////////
-//  Adjust hash function
-///////////////////////////////////////////////////////////////////////////////
+	/* Adjust hash function */
 	if (pHashFunc == NULL)
 		pHashFunc = TbixCalculateHash;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Build index file name
-///////////////////////////////////////////////////////////////////////////////
+	/* Build index file name */
 	char szIndexFile[SYS_MAX_PATH] = "";
 
 	if (TbixGetIndexFile(pszTabFilePath, piFieldsIdx, szIndexFile) < 0)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	FILE *pTabFile = fopen(pszTabFilePath, "rb");
 
 	if (pTabFile == NULL) {
 		ErrSetErrorCode(ERR_FILE_OPEN, pszTabFilePath);
-		return (ERR_FILE_OPEN);
+		return ERR_FILE_OPEN;
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  Calculate file lookup hash size
-///////////////////////////////////////////////////////////////////////////////
+	/* Calculate file lookup hash size */
 	char szLineBuffer[TAB_RECORD_BUFFER_SIZE] = "";
 	int iHashSize = TbixCalcHashSize(pTabFile, szLineBuffer, sizeof(szLineBuffer));
 
-///////////////////////////////////////////////////////////////////////////////
-//  Alloc and init hash records
-///////////////////////////////////////////////////////////////////////////////
+	/* Alloc and init hash records */
 	HashNode *pHash = (HashNode *) SysAlloc(iHashSize * sizeof(HashNode));
 
 	if (pHash == NULL) {
 		fclose(pTabFile);
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 	}
 
-	int ii;
+	int i;
 
-	for (ii = 0; ii < iHashSize; ii++) {
-		SYS_INIT_LIST_HEAD(&pHash[ii].NodeList);
-		pHash[ii].uCount = 0;
+	for (i = 0; i < iHashSize; i++) {
+		SYS_INIT_LIST_HEAD(&pHash[i].NodeList);
+		pHash[i].uCount = 0;
 	}
 
-///////////////////////////////////////////////////////////////////////////////
-//  Setup indexes records
-///////////////////////////////////////////////////////////////////////////////
+	/* Setup indexes records */
 	for (;;) {
-///////////////////////////////////////////////////////////////////////////////
-//  Get current offset
-///////////////////////////////////////////////////////////////////////////////
-		SYS_UINT32 uFileOffset = (SYS_UINT32) ftell(pTabFile);
+		/* Get current offset */
+		TabIdxUINT uFileOffset = (TabIdxUINT) ftell(pTabFile);
 
 		if (MscGetString(pTabFile, szLineBuffer, sizeof(szLineBuffer) - 1) == NULL)
 			break;
@@ -239,52 +221,44 @@ int TbixCreateIndex(char const *pszTabFilePath, int const *piFieldsIdx, bool bCa
 		if (ppszTabTokens == NULL)
 			continue;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Calculate hash value
-///////////////////////////////////////////////////////////////////////////////
-		SYS_UINT32 uHashVal = 0;
+		/* Calculate hash value */
+		TabIdxUINT uHashVal = 0;
 
-		if (pHashFunc(ppszTabTokens, piFieldsIdx, &uHashVal, bCaseSens) == 0) {
-			int iHashIndex = (int) (uHashVal % (SYS_UINT32) iHashSize);
+		if ((*pHashFunc)(ppszTabTokens, piFieldsIdx, &uHashVal, bCaseSens) == 0) {
+			int iHashIndex = (int) (uHashVal % (TabIdxUINT) iHashSize);
 			HashLink *pHL = (HashLink *) SysAlloc(sizeof(HashLink));
 
 			if (pHL == NULL) {
+				StrFreeStrings(ppszTabTokens);
 				TbixFreeHash(pHash, iHashSize);
 				fclose(pTabFile);
-				return (ErrGetErrorCode());
+				return ErrGetErrorCode();
 			}
 
 			pHL->uOffset = uFileOffset;
-
 			SYS_LIST_ADDT(&pHL->LLink, &pHash[iHashIndex].NodeList);
 			++pHash[iHashIndex].uCount;
 		}
-
 		StrFreeStrings(ppszTabTokens);
 	}
-
 	fclose(pTabFile);
 
-///////////////////////////////////////////////////////////////////////////////
-//  Write index file
-///////////////////////////////////////////////////////////////////////////////
+	/* Write index file */
 	FILE *pIndexFile = fopen(szIndexFile, "wb");
 
 	if (pIndexFile == NULL) {
 		TbixFreeHash(pHash, iHashSize);
 
 		ErrSetErrorCode(ERR_FILE_CREATE, szIndexFile);
-		return (ERR_FILE_CREATE);
+		return ERR_FILE_CREATE;
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  Write file header
-///////////////////////////////////////////////////////////////////////////////
+	/* Write file header */
 	HashFileHeader HFH;
 
 	ZeroData(HFH);
 	HFH.uMagic = TAB_INDEX_MAGIC;
 	HFH.uVersion = TAB_INDEX_CURR_VERSION;
-	HFH.uHashSize = (SYS_UINT32) iHashSize;
+	HFH.uHashSize = (TabIdxUINT) iHashSize;
 
 	if (!fwrite(&HFH, sizeof(HFH), 1, pIndexFile)) {
 		fclose(pIndexFile);
@@ -292,37 +266,31 @@ int TbixCreateIndex(char const *pszTabFilePath, int const *piFieldsIdx, bool bCa
 		TbixFreeHash(pHash, iHashSize);
 
 		ErrSetErrorCode(ERR_FILE_WRITE);
-		return (ERR_FILE_WRITE);
+		return ERR_FILE_WRITE;
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  Dump main table
-///////////////////////////////////////////////////////////////////////////////
-	SYS_UINT32 uCurrOffset = sizeof(HFH) + iHashSize * sizeof(SYS_UINT32);
+	/* Dump main table */
+	TabIdxUINT uCurrOffset = sizeof(HFH) + iHashSize * sizeof(TabIdxUINT);
 
-	for (ii = 0; ii < iHashSize; ii++) {
-		SYS_UINT32 uTableOffset = 0;
+	for (i = 0; i < iHashSize; i++) {
+		TabIdxUINT uTableOffset = 0;
 
-		if (pHash[ii].uCount != 0) {
+		if (pHash[i].uCount != 0) {
 			uTableOffset = uCurrOffset;
-
-			uCurrOffset += (pHash[ii].uCount + 1) * sizeof(SYS_UINT32);
+			uCurrOffset += (pHash[i].uCount + 1) * sizeof(TabIdxUINT);
 		}
-
 		if (!fwrite(&uTableOffset, sizeof(uTableOffset), 1, pIndexFile)) {
 			fclose(pIndexFile);
 			SysRemove(szIndexFile);
 			TbixFreeHash(pHash, iHashSize);
 
 			ErrSetErrorCode(ERR_FILE_WRITE);
-			return (ERR_FILE_WRITE);
+			return ERR_FILE_WRITE;
 		}
 	}
 
-///////////////////////////////////////////////////////////////////////////////
-//  Dump hash tables
-///////////////////////////////////////////////////////////////////////////////
-	for (ii = 0; ii < iHashSize; ii++) {
-		SYS_UINT32 uRecCount = pHash[ii].uCount;
+	/* Dump hash tables */
+	for (i = 0; i < iHashSize; i++) {
+		TabIdxUINT uRecCount = pHash[i].uCount;
 
 		if (uRecCount != 0) {
 			if (!fwrite(&uRecCount, sizeof(uRecCount), 1, pIndexFile)) {
@@ -331,15 +299,15 @@ int TbixCreateIndex(char const *pszTabFilePath, int const *piFieldsIdx, bool bCa
 				TbixFreeHash(pHash, iHashSize);
 
 				ErrSetErrorCode(ERR_FILE_WRITE);
-				return (ERR_FILE_WRITE);
+				return ERR_FILE_WRITE;
 			}
 
-			SysListHead *pHead = &pHash[ii].NodeList;
+			SysListHead *pHead = &pHash[i].NodeList;
 			SysListHead *pLLink;
 
 			SYS_LIST_FOR_EACH(pLLink, pHead) {
 				HashLink *pHL = SYS_LIST_ENTRY(pLLink, HashLink, LLink);
-				SYS_UINT32 uRecordOffset = pHL->uOffset;
+				TabIdxUINT uRecordOffset = pHL->uOffset;
 
 				if (!fwrite(&uRecordOffset, sizeof(uRecordOffset), 1, pIndexFile)) {
 					fclose(pIndexFile);
@@ -347,256 +315,214 @@ int TbixCreateIndex(char const *pszTabFilePath, int const *piFieldsIdx, bool bCa
 					TbixFreeHash(pHash, iHashSize);
 
 					ErrSetErrorCode(ERR_FILE_WRITE);
-					return (ERR_FILE_WRITE);
+					return ERR_FILE_WRITE;
 				}
 			}
 		}
 	}
-
 	fclose(pIndexFile);
-
 	TbixFreeHash(pHash, iHashSize);
 
-	return (0);
-
+	return 0;
 }
 
 static int TbixBuildKey(char *pszKey, va_list Args, bool bCaseSens)
 {
-
-	SetEmptyString(pszKey);
-
 	char const *pszToken;
 
-	for (int ii = 0; (pszToken = va_arg(Args, char *)) != NULL; ii++) {
-		if (ii > 0)
+	SetEmptyString(pszKey);
+	for (int i = 0; (pszToken = va_arg(Args, char *)) != NULL; i++) {
+		if (i > 0)
 			strcat(pszKey, TOKEN_SEP_STR);
-
 		strcat(pszKey, pszToken);
 	}
-
 	if (!bCaseSens)
 		StrLower(pszKey);
 
-	return (0);
-
+	return 0;
 }
 
 static int TbixBuildKey(char *pszKey, char const *const *ppszTabTokens,
 			int const *piFieldsIdx, bool bCaseSens)
 {
-
-	SetEmptyString(pszKey);
-
 	int iFieldsCount = StrStringsCount(ppszTabTokens);
 
-	for (int ii = 0; piFieldsIdx[ii] != INDEX_SEQUENCE_TERMINATOR; ii++) {
-		if ((piFieldsIdx[ii] < 0) || (piFieldsIdx[ii] >= iFieldsCount)) {
+	SetEmptyString(pszKey);
+	for (int i = 0; piFieldsIdx[i] != INDEX_SEQUENCE_TERMINATOR; i++) {
+		if (piFieldsIdx[i] < 0 || piFieldsIdx[i] >= iFieldsCount) {
 			ErrSetErrorCode(ERR_BAD_TAB_INDEX_FIELD);
-			return (ERR_BAD_TAB_INDEX_FIELD);
+			return ERR_BAD_TAB_INDEX_FIELD;
 		}
-
-		if (ii > 0)
+		if (i > 0)
 			strcat(pszKey, TOKEN_SEP_STR);
-
-		strcat(pszKey, ppszTabTokens[piFieldsIdx[ii]]);
+		strcat(pszKey, ppszTabTokens[piFieldsIdx[i]]);
 	}
-
 	if (!bCaseSens)
 		StrLower(pszKey);
 
-	return (0);
+	return 0;
+}
 
+static TabIdxUINT TbixHashData(char const *pData, long lSize)
+{
+	unsigned long ulHashVal = MscHashString(pData, lSize);
+
+	/*
+	 * We may want to use upper bits also, in architectures
+	 * where sizeof(long) > 4 ...
+	 */
+
+	return (TabIdxUINT) ulHashVal;
 }
 
 int TbixCalculateHash(char const *const *ppszTabTokens, int const *piFieldsIdx,
-		      SYS_UINT32 * puHashVal, bool bCaseSens)
+		      TabIdxUINT *puHashVal, bool bCaseSens)
 {
-
 	char szKey[KEY_BUFFER_SIZE] = "";
 
 	if (TbixBuildKey(szKey, ppszTabTokens, piFieldsIdx, bCaseSens) < 0)
-		return (ErrGetErrorCode());
-
-	*puHashVal = MscHashString(szKey, strlen(szKey));
-
-	return (0);
+		return ErrGetErrorCode();
+	*puHashVal = TbixHashData(szKey, strlen(szKey));
 
+	return 0;
 }
 
-static int TbixOpenIndex(char const *pszIndexFile, TabHashIndex & THI)
+static int TbixOpenIndex(char const *pszIndexFile, TabHashIndex &THI)
 {
-
 	FILE *pIndexFile = fopen(pszIndexFile, "rb");
 
 	if (pIndexFile == NULL) {
 		ErrSetErrorCode(ERR_FILE_OPEN, pszIndexFile);
-		return (ERR_FILE_OPEN);
+		return ERR_FILE_OPEN;
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  Read header and check signature
-///////////////////////////////////////////////////////////////////////////////
+	/* Read header and check signature */
 	ZeroData(THI);
 
 	if (!fread(&THI.HFH, sizeof(THI.HFH), 1, pIndexFile)) {
 		fclose(pIndexFile);
 
 		ErrSetErrorCode(ERR_FILE_READ, pszIndexFile);
-		return (ERR_FILE_READ);
+		return ERR_FILE_READ;
 	}
-
-	if ((THI.HFH.uMagic != TAB_INDEX_MAGIC) || (THI.HFH.uVersion != TAB_INDEX_CURR_VERSION)) {
+	if (THI.HFH.uMagic != TAB_INDEX_MAGIC || THI.HFH.uVersion != TAB_INDEX_CURR_VERSION) {
 		fclose(pIndexFile);
 
 		ErrSetErrorCode(ERR_BAD_INDEX_FILE, pszIndexFile);
-		return (ERR_BAD_INDEX_FILE);
+		return ERR_BAD_INDEX_FILE;
 	}
-
 	THI.pIndexFile = pIndexFile;
 
-	return (0);
-
+	return 0;
 }
 
-static int TbixCloseIndex(TabHashIndex & THI)
+static int TbixCloseIndex(TabHashIndex &THI)
 {
-
 	fclose(THI.pIndexFile);
-
 	ZeroData(THI);
 
-	return (0);
-
+	return 0;
 }
 
 static int TbixCheckIndex(char const *pszIndexFile)
 {
-
 	TabHashIndex THI;
 
 	if (TbixOpenIndex(pszIndexFile, THI) < 0)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
 	TbixCloseIndex(THI);
 
-	return (0);
-
+	return 0;
 }
 
-static SYS_UINT32 *TbixReadTable(TabHashIndex & THI, SYS_UINT32 uHashVal)
+static TabIdxUINT *TbixReadTable(TabHashIndex &THI, TabIdxUINT uHashVal)
 {
-
-	SYS_UINT32 uHashIndex = uHashVal % THI.HFH.uHashSize;
-	unsigned long ulTableOffset = sizeof(HashFileHeader) + uHashIndex * sizeof(SYS_UINT32);
+	TabIdxUINT uHashIndex = uHashVal % THI.HFH.uHashSize, uTableOffset, uTableSize;
+	unsigned long ulTableOffset = sizeof(HashFileHeader) + uHashIndex * sizeof(TabIdxUINT);
 
 	if (fseek(THI.pIndexFile, ulTableOffset, SEEK_SET) != 0) {
 		ErrSetErrorCode(ERR_BAD_INDEX_FILE);
-		return (NULL);
+		return NULL;
 	}
-
-	SYS_UINT32 uTableOffset;
-
 	if (!fread(&uTableOffset, sizeof(uTableOffset), 1, THI.pIndexFile)) {
 		ErrSetErrorCode(ERR_FILE_READ);
-		return (NULL);
+		return NULL;
 	}
-
 	if (uTableOffset == 0) {
 		ErrSetErrorCode(ERR_RECORD_NOT_FOUND);
-		return (NULL);
+		return NULL;
 	}
-
 	if (fseek(THI.pIndexFile, uTableOffset, SEEK_SET) != 0) {
 		ErrSetErrorCode(ERR_BAD_INDEX_FILE);
-		return (NULL);
+		return NULL;
 	}
-
-	SYS_UINT32 uTableSize;
-
 	if (!fread(&uTableSize, sizeof(uTableSize), 1, THI.pIndexFile)) {
 		ErrSetErrorCode(ERR_FILE_READ);
-		return (NULL);
+		return NULL;
 	}
 
-	SYS_UINT32 *pOffTable = (SYS_UINT32 *) SysAlloc((uTableSize + 1) * sizeof(SYS_UINT32));
+	TabIdxUINT *pOffTable = (TabIdxUINT *) SysAlloc((uTableSize + 1) * sizeof(TabIdxUINT));
 
 	if (pOffTable == NULL)
-		return (NULL);
+		return NULL;
 
 	pOffTable[0] = uTableSize;
-
-	if (!fread(&pOffTable[1], uTableSize * sizeof(SYS_UINT32), 1, THI.pIndexFile)) {
+	if (!fread(&pOffTable[1], uTableSize * sizeof(TabIdxUINT), 1, THI.pIndexFile)) {
 		SysFree(pOffTable);
 		ErrSetErrorCode(ERR_FILE_READ);
-		return (NULL);
+		return NULL;
 	}
 
-	return (pOffTable);
-
+	return pOffTable;
 }
 
 char **TbixLookup(char const *pszTabFilePath, int const *piFieldsIdx, bool bCaseSens, ...)
 {
-///////////////////////////////////////////////////////////////////////////////
-//  Build index file name
-///////////////////////////////////////////////////////////////////////////////
+	/* Build index file name */
 	char szIndexFile[SYS_MAX_PATH] = "";
 
 	if (TbixGetIndexFile(pszTabFilePath, piFieldsIdx, szIndexFile) < 0)
-		return (NULL);
+		return NULL;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Calculate key & hash
-///////////////////////////////////////////////////////////////////////////////
+	/* Calculate key & hash */
 	va_list Args;
-
-	va_start(Args, bCaseSens);
-
 	char szRefKey[KEY_BUFFER_SIZE] = "";
 
+	va_start(Args, bCaseSens);
 	if (TbixBuildKey(szRefKey, Args, bCaseSens) < 0) {
 		va_end(Args);
-		return (NULL);
+		return NULL;
 	}
-
 	va_end(Args);
 
-	SYS_UINT32 uHashVal = MscHashString(szRefKey, strlen(szRefKey));
+	TabIdxUINT uHashVal = TbixHashData(szRefKey, strlen(szRefKey));
 
-///////////////////////////////////////////////////////////////////////////////
-//  Open index
-///////////////////////////////////////////////////////////////////////////////
+	/* Open index */
 	TabHashIndex THI;
 
 	if (TbixOpenIndex(szIndexFile, THI) < 0)
-		return (NULL);
+		return NULL;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Try to lookup records
-///////////////////////////////////////////////////////////////////////////////
-	SYS_UINT32 *pHashTable = TbixReadTable(THI, uHashVal);
+	/* Try to lookup records */
+	TabIdxUINT *pHashTable = TbixReadTable(THI, uHashVal);
 
 	TbixCloseIndex(THI);
-
 	if (pHashTable == NULL)
-		return (NULL);
+		return NULL;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Search for the matched one
-///////////////////////////////////////////////////////////////////////////////
+	/* Search for the matched one */
 	FILE *pTabFile = fopen(pszTabFilePath, "rb");
 
 	if (pTabFile == NULL) {
 		SysFree(pHashTable);
-
 		ErrSetErrorCode(ERR_FILE_OPEN, pszTabFilePath);
-		return (NULL);
+		return NULL;
 	}
 
 	int iHashNodes = (int) pHashTable[0];
 
-	for (int ii = 0; ii < iHashNodes; ii++) {
-		char **ppszTabTokens = TbixLoadRecord(pTabFile, pHashTable[ii + 1]);
+	for (int i = 0; i < iHashNodes; i++) {
+		char **ppszTabTokens = TbixLoadRecord(pTabFile, pHashTable[i + 1]);
 
 		if (ppszTabTokens != NULL) {
 			char szKey[KEY_BUFFER_SIZE] = "";
@@ -606,179 +532,182 @@ char **TbixLookup(char const *pszTabFilePath, int const *piFieldsIdx, bool bCase
 					if (strcmp(szKey, szRefKey) == 0) {
 						fclose(pTabFile);
 						SysFree(pHashTable);
-						return (ppszTabTokens);
+						return ppszTabTokens;
 					}
 				} else {
 					if (stricmp(szKey, szRefKey) == 0) {
 						fclose(pTabFile);
 						SysFree(pHashTable);
-						return (ppszTabTokens);
+						return ppszTabTokens;
 					}
 				}
 			}
-
 			StrFreeStrings(ppszTabTokens);
 		}
 	}
-
 	fclose(pTabFile);
-
 	SysFree(pHashTable);
 
 	ErrSetErrorCode(ERR_RECORD_NOT_FOUND);
 
-	return (NULL);
-
+	return NULL;
 }
 
-static char **TbixLoadRecord(FILE * pTabFile, SYS_UINT32 uOffset)
+static char **TbixLoadRecord(FILE *pTabFile, TabIdxUINT uOffset)
 {
+	char szLineBuffer[TAB_RECORD_BUFFER_SIZE] = "";
 
 	if (fseek(pTabFile, uOffset, SEEK_SET) != 0) {
 		ErrSetErrorCode(ERR_BAD_INDEX_FILE);
-		return (NULL);
+		return NULL;
 	}
-
-	char szLineBuffer[TAB_RECORD_BUFFER_SIZE] = "";
-
 	if (MscGetString(pTabFile, szLineBuffer, sizeof(szLineBuffer) - 1) == NULL) {
 		ErrSetErrorCode(ERR_FILE_READ);
-		return (NULL);
+		return NULL;
 	}
 
-	return (StrGetTabLineStrings(szLineBuffer));
-
+	return StrGetTabLineStrings(szLineBuffer);
 }
 
 int TbixCheckIndex(char const *pszTabFilePath, int const *piFieldsIdx, bool bCaseSens,
-		   int (*pHashFunc) (char const *const *, int const *, SYS_UINT32 *, bool))
+		   int (*pHashFunc) (char const *const *, int const *, TabIdxUINT *, bool))
 {
-
 	SYS_FILE_INFO FI_Tab;
 
 	if (SysGetFileInfo(pszTabFilePath, FI_Tab) < 0)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
-///////////////////////////////////////////////////////////////////////////////
-//  Build index file name
-///////////////////////////////////////////////////////////////////////////////
+	/* Build index file name */
 	char szIndexFile[SYS_MAX_PATH] = "";
 
 	if (TbixGetIndexFile(pszTabFilePath, piFieldsIdx, szIndexFile) < 0)
-		return (ErrGetErrorCode());
+		return ErrGetErrorCode();
 
-///////////////////////////////////////////////////////////////////////////////
-//  Compare TAB <-> Index dates
-///////////////////////////////////////////////////////////////////////////////
+	/* Compare TAB <-> Index dates */
 	SYS_FILE_INFO FI_Index;
 
-	if ((SysGetFileInfo(szIndexFile, FI_Index) < 0) || (FI_Tab.tMod > FI_Index.tMod) ||
-	    (TbixCheckIndex(szIndexFile) < 0)) {
+	if (SysGetFileInfo(szIndexFile, FI_Index) < 0 || FI_Tab.tMod > FI_Index.tMod ||
+	    TbixCheckIndex(szIndexFile) < 0) {
 
-///////////////////////////////////////////////////////////////////////////////
-//  Rebuild the index
-///////////////////////////////////////////////////////////////////////////////
+		/* Rebuild the index */
 		if (TbixCreateIndex(pszTabFilePath, piFieldsIdx, bCaseSens, pHashFunc) < 0)
-			return (ErrGetErrorCode());
-
+			return ErrGetErrorCode();
 	}
 
-	return (0);
-
+	return 0;
 }
 
 INDEX_HANDLE TbixOpenHandle(char const *pszTabFilePath, int const *piFieldsIdx,
-			    SYS_UINT32 uHashVal)
+			    TabIdxUINT const *puHashVal, int iNumVals)
 {
-///////////////////////////////////////////////////////////////////////////////
-//  Build index file name
-///////////////////////////////////////////////////////////////////////////////
+	int i;
+	long lRecCount;
+	ARRAY_HANDLE hArray;
+	TabHashIndex THI;
 	char szIndexFile[SYS_MAX_PATH] = "";
 
-	if (TbixGetIndexFile(pszTabFilePath, piFieldsIdx, szIndexFile) < 0)
-		return (INVALID_INDEX_HANDLE);
+	if (TbixGetIndexFile(pszTabFilePath, piFieldsIdx, szIndexFile) < 0 ||
+	    (hArray = ArrayCreate(TAB_INIT_RESSET_SIZE)) == INVALID_ARRAY_HANDLE)
+		return INVALID_INDEX_HANDLE;
 
-///////////////////////////////////////////////////////////////////////////////
-//  Open index
-///////////////////////////////////////////////////////////////////////////////
-	TabHashIndex THI;
-
-	if (TbixOpenIndex(szIndexFile, THI) < 0)
-		return (INVALID_INDEX_HANDLE);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Try to lookup records
-///////////////////////////////////////////////////////////////////////////////
-	SYS_UINT32 *pHashTable = TbixReadTable(THI, uHashVal);
+	if (TbixOpenIndex(szIndexFile, THI) < 0) {
+		ArrayFree(hArray, MscSysFreeCB, NULL);
+		return INVALID_INDEX_HANDLE;
+	}
+	for (i = 0, lRecCount = 0; i < iNumVals; i++) {
+		TabIdxUINT *pHashTable = TbixReadTable(THI, puHashVal[i]);
 
+		if (pHashTable != NULL) {
+			if (ArrayAppend(hArray, pHashTable) < 0) {
+				SysFree(pHashTable);
+				ArrayFree(hArray, MscSysFreeCB, NULL);
+				TbixCloseIndex(THI);
+				return INVALID_INDEX_HANDLE;
+			}
+			lRecCount += (long) pHashTable[0];
+		}
+	}
 	TbixCloseIndex(THI);
+	if (lRecCount == 0) {
+		ArrayFree(hArray, MscSysFreeCB, NULL);
+		ErrSetErrorCode(ERR_RECORD_NOT_FOUND);
+		return INVALID_INDEX_HANDLE;
+	}
 
-	if (pHashTable == NULL)
-		return (INVALID_INDEX_HANDLE);
-
-///////////////////////////////////////////////////////////////////////////////
-//  Open tab file
-///////////////////////////////////////////////////////////////////////////////
+	/* Open tab file */
 	FILE *pTabFile = fopen(pszTabFilePath, "rb");
 
 	if (pTabFile == NULL) {
-		SysFree(pHashTable);
-
+		ArrayFree(hArray, MscSysFreeCB, NULL);
 		ErrSetErrorCode(ERR_FILE_OPEN, pszTabFilePath);
-		return (INVALID_INDEX_HANDLE);
+		return INVALID_INDEX_HANDLE;
 	}
-///////////////////////////////////////////////////////////////////////////////
-//  Setup lookup struct
-///////////////////////////////////////////////////////////////////////////////
+	/* Setup lookup struct */
 	IndexLookupData *pILD = (IndexLookupData *) SysAlloc(sizeof(IndexLookupData));
 
 	if (pILD == NULL) {
 		fclose(pTabFile);
-		SysFree(pHashTable);
-		return (INVALID_INDEX_HANDLE);
+		ArrayFree(hArray, MscSysFreeCB, NULL);
+		return INVALID_INDEX_HANDLE;
 	}
-
+	pILD->hArray = hArray;
+	pILD->lRecCount = lRecCount;
 	pILD->pTabFile = pTabFile;
-	pILD->pHashTable = pHashTable;
-
-	return ((INDEX_HANDLE) pILD);
 
+	return (INDEX_HANDLE) pILD;
 }
 
 int TbixCloseHandle(INDEX_HANDLE hIndexLookup)
 {
-
 	IndexLookupData *pILD = (IndexLookupData *) hIndexLookup;
 
 	fclose(pILD->pTabFile);
-
-	SysFree(pILD->pHashTable);
-
+	ArrayFree(pILD->hArray, MscSysFreeCB, NULL);
 	SysFree(pILD);
 
-	return (0);
-
+	return 0;
 }
 
-int TbixLookedUpRecords(INDEX_HANDLE hIndexLookup)
+long TbixLookedUpRecords(INDEX_HANDLE hIndexLookup)
 {
-
 	IndexLookupData *pILD = (IndexLookupData *) hIndexLookup;
 
-	return ((int) pILD->pHashTable[0]);
-
+	return pILD->lRecCount;
 }
 
-char **TbixGetRecord(INDEX_HANDLE hIndexLookup, int iRecord)
+char **TbixFirstRecord(INDEX_HANDLE hIndexLookup)
 {
-
 	IndexLookupData *pILD = (IndexLookupData *) hIndexLookup;
 
-	if ((iRecord < 0) || (iRecord >= (int) pILD->pHashTable[0])) {
+	pILD->lArIdx = 0;
+	pILD->lHTblI = 0;
+	if ((pILD->pHTblC = (TabIdxUINT *) ArrayGet(pILD->hArray,
+						    pILD->lArIdx)) == NULL) {
 		ErrSetErrorCode(ERR_RECORD_NOT_FOUND);
-		return (NULL);
+		return NULL;
 	}
 
-	return (TbixLoadRecord(pILD->pTabFile, pILD->pHashTable[iRecord + 1]));
-
+	return TbixLoadRecord(pILD->pTabFile, pILD->pHTblC[++pILD->lHTblI]);
 }
+
+char **TbixNextRecord(INDEX_HANDLE hIndexLookup)
+{
+	IndexLookupData *pILD = (IndexLookupData *) hIndexLookup;
+
+	if (pILD->pHTblC == NULL) {
+		ErrSetErrorCode(ERR_BAD_SEQUENCE);
+		return NULL;
+	}
+	if (pILD->lHTblI == (long) pILD->pHTblC[0]) {
+		pILD->lArIdx++;
+		if ((pILD->pHTblC = (TabIdxUINT *) ArrayGet(pILD->hArray,
+							    pILD->lArIdx)) == NULL) {
+			ErrSetErrorCode(ERR_RECORD_NOT_FOUND);
+			return NULL;
+		}
+		pILD->lHTblI = 0;
+	}
+
+	return TbixLoadRecord(pILD->pTabFile, pILD->pHTblC[++pILD->lHTblI]);
+}
+
